/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtOpenGLAPI_H
#define _QtOpenGLAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtOpenGL[0]
#define sipNameNr_QOpenGLFramebufferObject__FramebufferRestorePolicy 57
#define sipName_QOpenGLFramebufferObject__FramebufferRestorePolicy &sipStrings_QtOpenGL[57]
#define sipNameNr_108 108
#define sipName_108 &sipStrings_QtOpenGL[108]
#define sipNameNr_147 147
#define sipName_147 &sipStrings_QtOpenGL[147]
#define sipNameNr_185 185
#define sipName_185 &sipStrings_QtOpenGL[185]
#define sipNameNr_QOpenGLFramebufferObject__Attachment 222
#define sipName_QOpenGLFramebufferObject__Attachment &sipStrings_QtOpenGL[222]
#define sipNameNr_259 259
#define sipName_259 &sipStrings_QtOpenGL[259]
#define sipNameNr_QOpenGLTexture__CoordinateDirection 295
#define sipName_QOpenGLTexture__CoordinateDirection &sipStrings_QtOpenGL[295]
#define sipNameNr_QOpenGLTexture__ComparisonFunction 331
#define sipName_QOpenGLTexture__ComparisonFunction &sipStrings_QtOpenGL[331]
#define sipNameNr_RestoreFramebufferBindingToDefault 366
#define sipName_RestoreFramebufferBindingToDefault &sipStrings_QtOpenGL[366]
#define sipNameNr_401 401
#define sipName_401 &sipStrings_QtOpenGL[401]
#define sipNameNr_setDefaultInnerTessellationLevels 435
#define sipName_setDefaultInnerTessellationLevels &sipStrings_QtOpenGL[435]
#define sipNameNr_setDefaultOuterTessellationLevels 469
#define sipName_setDefaultOuterTessellationLevels &sipStrings_QtOpenGL[469]
#define sipNameNr_QOpenGLTexture__DepthStencilMode 503
#define sipName_QOpenGLTexture__DepthStencilMode &sipStrings_QtOpenGL[503]
#define sipNameNr_QOpenGLTexture__MipMapGeneration 536
#define sipName_QOpenGLTexture__MipMapGeneration &sipStrings_QtOpenGL[536]
#define sipNameNr_QOpenGLTexture__SwizzleComponent 569
#define sipName_QOpenGLTexture__SwizzleComponent &sipStrings_QtOpenGL[569]
#define sipNameNr_QOpenGLTexture__TextureUnitReset 602
#define sipName_QOpenGLTexture__TextureUnitReset &sipStrings_QtOpenGL[602]
#define sipNameNr_QOpenGLVertexArrayObject__Binder 635
#define sipName_QOpenGLVertexArrayObject__Binder &sipStrings_QtOpenGL[635]
#define sipNameNr_addCacheableShaderFromSourceCode 668
#define sipName_addCacheableShaderFromSourceCode &sipStrings_QtOpenGL[668]
#define sipNameNr_addCacheableShaderFromSourceFile 701
#define sipName_addCacheableShaderFromSourceFile &sipStrings_QtOpenGL[701]
#define sipNameNr_glRenderbufferStorageMultisample 734
#define sipName_glRenderbufferStorageMultisample &sipStrings_QtOpenGL[734]
#define sipNameNr_BindingTarget2DMultisampleArray 767
#define sipName_BindingTarget2DMultisampleArray &sipStrings_QtOpenGL[767]
#define sipNameNr_799 799
#define sipName_799 &sipStrings_QtOpenGL[799]
#define sipNameNr_QOpenGLDebugLogger__LoggingMode 831
#define sipName_QOpenGLDebugLogger__LoggingMode &sipStrings_QtOpenGL[831]
#define sipNameNr_QOpenGLBuffer__RangeAccessFlag 863
#define sipName_QOpenGLBuffer__RangeAccessFlag &sipStrings_QtOpenGL[863]
#define sipNameNr_QOpenGLFramebufferObjectFormat 894
#define sipName_QOpenGLFramebufferObjectFormat &sipStrings_QtOpenGL[894]
#define sipNameNr_QOpenGLTexture__ComparisonMode 925
#define sipName_QOpenGLTexture__ComparisonMode &sipStrings_QtOpenGL[925]
#define sipNameNr_QOpenGLVersionFunctionsFactory 956
#define sipName_QOpenGLVersionFunctionsFactory &sipStrings_QtOpenGL[956]
#define sipNameNr_SRGB8_PunchThrough_Alpha1_ETC2 987
#define sipName_SRGB8_PunchThrough_Alpha1_ETC2 &sipStrings_QtOpenGL[987]
#define sipNameNr_defaultInnerTessellationLevels 1018
#define sipName_defaultInnerTessellationLevels &sipStrings_QtOpenGL[1018]
#define sipNameNr_defaultOuterTessellationLevels 1049
#define sipName_defaultOuterTessellationLevels &sipStrings_QtOpenGL[1049]
#define sipNameNr_setAutoMipMapGenerationEnabled 1080
#define sipName_setAutoMipMapGenerationEnabled &sipStrings_QtOpenGL[1080]
#define sipNameNr_DontRestoreFramebufferBinding 1111
#define sipName_DontRestoreFramebufferBinding &sipStrings_QtOpenGL[1111]
#define sipNameNr_QOpenGLDebugMessage__Severity 1141
#define sipName_QOpenGLDebugMessage__Severity &sipStrings_QtOpenGL[1141]
#define sipNameNr_QOpenGLTexture__BindingTarget 1171
#define sipName_QOpenGLTexture__BindingTarget &sipStrings_QtOpenGL[1171]
#define sipNameNr_QOpenGLTexture__TextureFormat 1201
#define sipName_QOpenGLTexture__TextureFormat &sipStrings_QtOpenGL[1201]
#define sipNameNr_QOpenGLTextureBlitter__Origin 1231
#define sipName_QOpenGLTextureBlitter__Origin &sipStrings_QtOpenGL[1231]
#define sipNameNr_QOpenGLWindow__UpdateBehavior 1261
#define sipName_QOpenGLWindow__UpdateBehavior &sipStrings_QtOpenGL[1261]
#define sipNameNr_RGB8_PunchThrough_Alpha1_ETC2 988
#define sipName_RGB8_PunchThrough_Alpha1_ETC2 &sipStrings_QtOpenGL[988]
#define sipNameNr_glDrawTransformFeedbackStream 1291
#define sipName_glDrawTransformFeedbackStream &sipStrings_QtOpenGL[1291]
#define sipNameNr_isAutoMipMapGenerationEnabled 1321
#define sipName_isAutoMipMapGenerationEnabled &sipStrings_QtOpenGL[1321]
#define sipNameNr_QOpenGLShader__ShaderTypeBit 1351
#define sipName_QOpenGLShader__ShaderTypeBit &sipStrings_QtOpenGL[1351]
#define sipNameNr_QOpenGLTexture__SwizzleValue 1380
#define sipName_QOpenGLTexture__SwizzleValue &sipStrings_QtOpenGL[1380]
#define sipNameNr_setLeastSignificantByteFirst 1409
#define sipName_setLeastSignificantByteFirst &sipStrings_QtOpenGL[1409]
#define sipNameNr_ImmutableMultisampleStorage 1438
#define sipName_ImmutableMultisampleStorage &sipStrings_QtOpenGL[1438]
#define sipNameNr_QOpenGLBuffer__UsagePattern 1466
#define sipName_QOpenGLBuffer__UsagePattern &sipStrings_QtOpenGL[1466]
#define sipNameNr_QOpenGLDebugMessage__Source 1494
#define sipName_QOpenGLDebugMessage__Source &sipStrings_QtOpenGL[1494]
#define sipNameNr_QOpenGLPixelTransferOptions 1522
#define sipName_QOpenGLPixelTransferOptions &sipStrings_QtOpenGL[1522]
#define sipNameNr_QOpenGLTexture__CubeMapFace 1550
#define sipName_QOpenGLTexture__CubeMapFace &sipStrings_QtOpenGL[1550]
#define sipNameNr_QOpenGLTexture__PixelFormat 1578
#define sipName_QOpenGLTexture__PixelFormat &sipStrings_QtOpenGL[1578]
#define sipNameNr_glGetConvolutionParameterfv 1606
#define sipName_glGetConvolutionParameterfv &sipStrings_QtOpenGL[1606]
#define sipNameNr_glGetConvolutionParameteriv 1634
#define sipName_glGetConvolutionParameteriv &sipStrings_QtOpenGL[1634]
#define sipNameNr_hasOpenGLFramebufferObjects 1662
#define sipName_hasOpenGLFramebufferObjects &sipStrings_QtOpenGL[1662]
#define sipNameNr_BindingTarget2DMultisample 1690
#define sipName_BindingTarget2DMultisample &sipStrings_QtOpenGL[1690]
#define sipNameNr_1717 1717
#define sipName_1717 &sipStrings_QtOpenGL[1717]
#define sipNameNr_TextureComparisonOperators 1744
#define sipName_TextureComparisonOperators &sipStrings_QtOpenGL[1744]
#define sipNameNr_glDisableVertexAttribArray 1771
#define sipName_glDisableVertexAttribArray &sipStrings_QtOpenGL[1771]
#define sipNameNr_glGetColorTableParameterfv 1798
#define sipName_glGetColorTableParameterfv &sipStrings_QtOpenGL[1798]
#define sipNameNr_glGetColorTableParameteriv 1825
#define sipName_glGetColorTableParameteriv &sipStrings_QtOpenGL[1825]
#define sipNameNr_isLeastSignificantBitFirst 1852
#define sipName_isLeastSignificantBitFirst &sipStrings_QtOpenGL[1852]
#define sipNameNr_BindingTargetCubeMapArray 1879
#define sipName_BindingTargetCubeMapArray &sipStrings_QtOpenGL[1879]
#define sipNameNr_Float32_D32_UInt32_S8_X24 1905
#define sipName_Float32_D32_UInt32_S8_X24 &sipStrings_QtOpenGL[1905]
#define sipNameNr_QOpenGLDebugMessage__Type 1931
#define sipName_QOpenGLDebugMessage__Type &sipStrings_QtOpenGL[1931]
#define sipNameNr_QOpenGLFunctions_4_1_Core 1957
#define sipName_QOpenGLFunctions_4_1_Core &sipStrings_QtOpenGL[1957]
#define sipNameNr_QOpenGLTexture__PixelType 1983
#define sipName_QOpenGLTexture__PixelType &sipStrings_QtOpenGL[1983]
#define sipNameNr_RestoreFrameBufferBinding 2009
#define sipName_RestoreFrameBufferBinding &sipStrings_QtOpenGL[2009]
#define sipNameNr_glCompressedTexSubImage1D 2035
#define sipName_glCompressedTexSubImage1D &sipStrings_QtOpenGL[2035]
#define sipNameNr_glCompressedTexSubImage2D 2061
#define sipName_glCompressedTexSubImage2D &sipStrings_QtOpenGL[2061]
#define sipNameNr_glCompressedTexSubImage3D 2087
#define sipName_glCompressedTexSubImage3D &sipStrings_QtOpenGL[2087]
#define sipNameNr_glCopyConvolutionFilter1D 2113
#define sipName_glCopyConvolutionFilter1D &sipStrings_QtOpenGL[2113]
#define sipNameNr_glCopyConvolutionFilter2D 2139
#define sipName_glCopyConvolutionFilter2D &sipStrings_QtOpenGL[2139]
#define sipNameNr_glEnableVertexAttribArray 2165
#define sipName_glEnableVertexAttribArray &sipStrings_QtOpenGL[2165]
#define sipNameNr_glFramebufferRenderbuffer 2191
#define sipName_glFramebufferRenderbuffer &sipStrings_QtOpenGL[2191]
#define sipNameNr_glFramebufferTextureLayer 2217
#define sipName_glFramebufferTextureLayer &sipStrings_QtOpenGL[2217]
#define sipNameNr_glResumeTransformFeedback 2243
#define sipName_glResumeTransformFeedback &sipStrings_QtOpenGL[2243]
#define sipNameNr_glValidateProgramPipeline 2269
#define sipName_glValidateProgramPipeline &sipStrings_QtOpenGL[2269]
#define sipNameNr_initializeOpenGLFunctions 2295
#define sipName_initializeOpenGLFunctions &sipStrings_QtOpenGL[2295]
#define sipNameNr_maxGeometryOutputVertices 2321
#define sipName_maxGeometryOutputVertices &sipStrings_QtOpenGL[2321]
#define sipNameNr_supportsExternalOESTarget 2347
#define sipName_supportsExternalOESTarget &sipStrings_QtOpenGL[2347]
#define sipNameNr_FramebufferRestorePolicy 83
#define sipName_FramebufferRestorePolicy &sipStrings_QtOpenGL[83]
#define sipNameNr_QAbstractOpenGLFunctions 2373
#define sipName_QAbstractOpenGLFunctions &sipStrings_QtOpenGL[2373]
#define sipNameNr_QOpenGLFramebufferObject 2398
#define sipName_QOpenGLFramebufferObject &sipStrings_QtOpenGL[2398]
#define sipNameNr_QOpenGLTexture__WrapMode 2423
#define sipName_QOpenGLTexture__WrapMode &sipStrings_QtOpenGL[2423]
#define sipNameNr_QOpenGLVertexArrayObject 2448
#define sipName_QOpenGLVertexArrayObject &sipStrings_QtOpenGL[2448]
#define sipNameNr_Target2DMultisampleArray 774
#define sipName_Target2DMultisampleArray &sipStrings_QtOpenGL[774]
#define sipNameNr_createApplicationMessage 2473
#define sipName_createApplicationMessage &sipStrings_QtOpenGL[2473]
#define sipNameNr_defaultFramebufferObject 2498
#define sipName_defaultFramebufferObject &sipStrings_QtOpenGL[2498]
#define sipNameNr_glBeginConditionalRender 2523
#define sipName_glBeginConditionalRender &sipStrings_QtOpenGL[2523]
#define sipNameNr_glBeginTransformFeedback 2548
#define sipName_glBeginTransformFeedback &sipStrings_QtOpenGL[2548]
#define sipNameNr_glBlendEquationSeparatei 2573
#define sipName_glBlendEquationSeparatei &sipStrings_QtOpenGL[2573]
#define sipNameNr_glCheckFramebufferStatus 2598
#define sipName_glCheckFramebufferStatus &sipStrings_QtOpenGL[2598]
#define sipNameNr_glConvolutionParameterfv 2623
#define sipName_glConvolutionParameterfv &sipStrings_QtOpenGL[2623]
#define sipNameNr_glConvolutionParameteriv 2648
#define sipName_glConvolutionParameteriv &sipStrings_QtOpenGL[2648]
#define sipNameNr_glGetTexLevelParameterfv 2673
#define sipName_glGetTexLevelParameterfv &sipStrings_QtOpenGL[2673]
#define sipNameNr_glGetTexLevelParameteriv 2698
#define sipName_glGetTexLevelParameteriv &sipStrings_QtOpenGL[2698]
#define sipNameNr_glPauseTransformFeedback 2723
#define sipName_glPauseTransformFeedback &sipStrings_QtOpenGL[2723]
#define sipNameNr_hasOpenGLFramebufferBlit 2748
#define sipName_hasOpenGLFramebufferBlit &sipStrings_QtOpenGL[2748]
#define sipNameNr_setInternalTextureFormat 2773
#define sipName_setInternalTextureFormat &sipStrings_QtOpenGL[2773]
#define sipNameNr_PyQt6_sip_simplewrapper 2798
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtOpenGL[2798]
#define sipNameNr_QOpenGLTexture__Feature 2822
#define sipName_QOpenGLTexture__Feature &sipStrings_QtOpenGL[2822]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x10 2846
#define sipName_SRGB8_Alpha8_ASTC_10x10 &sipStrings_QtOpenGL[2846]
#define sipNameNr_SRGB8_Alpha8_ASTC_12x10 2870
#define sipName_SRGB8_Alpha8_ASTC_12x10 &sipStrings_QtOpenGL[2870]
#define sipNameNr_SRGB8_Alpha8_ASTC_12x12 2894
#define sipName_SRGB8_Alpha8_ASTC_12x12 &sipStrings_QtOpenGL[2894]
#define sipNameNr_addShaderFromSourceCode 2918
#define sipName_addShaderFromSourceCode &sipStrings_QtOpenGL[2918]
#define sipNameNr_addShaderFromSourceFile 2942
#define sipName_addShaderFromSourceFile &sipStrings_QtOpenGL[2942]
#define sipNameNr_createThirdPartyMessage 2966
#define sipName_createThirdPartyMessage &sipStrings_QtOpenGL[2966]
#define sipNameNr_glBindTransformFeedback 2990
#define sipName_glBindTransformFeedback &sipStrings_QtOpenGL[2990]
#define sipNameNr_glBlendEquationSeparate 3014
#define sipName_glBlendEquationSeparate &sipStrings_QtOpenGL[3014]
#define sipNameNr_glColorTableParameterfv 3038
#define sipName_glColorTableParameterfv &sipStrings_QtOpenGL[3038]
#define sipNameNr_glColorTableParameteriv 3062
#define sipName_glColorTableParameteriv &sipStrings_QtOpenGL[3062]
#define sipNameNr_glConvolutionParameterf 3086
#define sipName_glConvolutionParameterf &sipStrings_QtOpenGL[3086]
#define sipNameNr_glConvolutionParameteri 3110
#define sipName_glConvolutionParameteri &sipStrings_QtOpenGL[3110]
#define sipNameNr_glDrawTransformFeedback 3134
#define sipName_glDrawTransformFeedback &sipStrings_QtOpenGL[3134]
#define sipNameNr_glPrimitiveRestartIndex 3158
#define sipName_glPrimitiveRestartIndex &sipStrings_QtOpenGL[3158]
#define sipNameNr_glReleaseShaderCompiler 3182
#define sipName_glReleaseShaderCompiler &sipStrings_QtOpenGL[3182]
#define sipNameNr_glSecondaryColorPointer 3206
#define sipName_glSecondaryColorPointer &sipStrings_QtOpenGL[3206]
#define sipNameNr_glTexImage2DMultisample 3230
#define sipName_glTexImage2DMultisample &sipStrings_QtOpenGL[3230]
#define sipNameNr_glTexImage3DMultisample 3254
#define sipName_glTexImage3DMultisample &sipStrings_QtOpenGL[3254]
#define sipNameNr_hasOpenGLShaderPrograms 3278
#define sipName_hasOpenGLShaderPrograms &sipStrings_QtOpenGL[3278]
#define sipNameNr_setFixedSamplePositions 3302
#define sipName_setFixedSamplePositions &sipStrings_QtOpenGL[3302]
#define sipNameNr_setMaximumLevelOfDetail 3326
#define sipName_setMaximumLevelOfDetail &sipStrings_QtOpenGL[3326]
#define sipNameNr_setMinimumLevelOfDetail 3350
#define sipName_setMinimumLevelOfDetail &sipStrings_QtOpenGL[3350]
#define sipNameNr_supportsRectangleTarget 3374
#define sipName_supportsRectangleTarget &sipStrings_QtOpenGL[3374]
#define sipNameNr_BindingTargetRectangle 3398
#define sipName_BindingTargetRectangle &sipStrings_QtOpenGL[3398]
#define sipNameNr_DeprecatedBehaviorType 3421
#define sipName_DeprecatedBehaviorType &sipStrings_QtOpenGL[3421]
#define sipNameNr_QOpenGLTexture__Filter 3444
#define sipName_QOpenGLTexture__Filter &sipStrings_QtOpenGL[3444]
#define sipNameNr_QOpenGLTexture__Target 3467
#define sipName_QOpenGLTexture__Target &sipStrings_QtOpenGL[3467]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x5 3490
#define sipName_SRGB8_Alpha8_ASTC_10x5 &sipStrings_QtOpenGL[3490]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x6 3513
#define sipName_SRGB8_Alpha8_ASTC_10x6 &sipStrings_QtOpenGL[3513]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x8 3536
#define sipName_SRGB8_Alpha8_ASTC_10x8 &sipStrings_QtOpenGL[3536]
#define sipNameNr_TessellationEvaluation 3559
#define sipName_TessellationEvaluation &sipStrings_QtOpenGL[3559]
#define sipNameNr_glCompressedTexImage1D 3582
#define sipName_glCompressedTexImage1D &sipStrings_QtOpenGL[3582]
#define sipNameNr_glCompressedTexImage2D 3605
#define sipName_glCompressedTexImage2D &sipStrings_QtOpenGL[3605]
#define sipNameNr_glCompressedTexImage3D 3628
#define sipName_glCompressedTexImage3D &sipStrings_QtOpenGL[3628]
#define sipNameNr_glEndConditionalRender 3651
#define sipName_glEndConditionalRender &sipStrings_QtOpenGL[3651]
#define sipNameNr_glEndTransformFeedback 3674
#define sipName_glEndTransformFeedback &sipStrings_QtOpenGL[3674]
#define sipNameNr_glFramebufferTexture1D 3697
#define sipName_glFramebufferTexture1D &sipStrings_QtOpenGL[3697]
#define sipNameNr_glFramebufferTexture2D 3720
#define sipName_glFramebufferTexture2D &sipStrings_QtOpenGL[3720]
#define sipNameNr_glFramebufferTexture3D 3743
#define sipName_glFramebufferTexture3D &sipStrings_QtOpenGL[3743]
#define sipNameNr_glGetBufferParameteriv 3766
#define sipName_glGetBufferParameteriv &sipStrings_QtOpenGL[3766]
#define sipNameNr_glLoadTransposeMatrixd 3789
#define sipName_glLoadTransposeMatrixd &sipStrings_QtOpenGL[3789]
#define sipNameNr_glLoadTransposeMatrixf 3812
#define sipName_glLoadTransposeMatrixf &sipStrings_QtOpenGL[3812]
#define sipNameNr_glMultTransposeMatrixd 3835
#define sipName_glMultTransposeMatrixd &sipStrings_QtOpenGL[3835]
#define sipNameNr_glMultTransposeMatrixf 3858
#define sipName_glMultTransposeMatrixf &sipStrings_QtOpenGL[3858]
#define sipNameNr_isFixedSamplePositions 3881
#define sipName_isFixedSamplePositions &sipStrings_QtOpenGL[3881]
#define sipNameNr_setMagnificationFilter 3904
#define sipName_setMagnificationFilter &sipStrings_QtOpenGL[3904]
#define sipNameNr_3927 3927
#define sipName_3927 &sipStrings_QtOpenGL[3927]
#define sipNameNr_QOpenGLBuffer__Access 3949
#define sipName_QOpenGLBuffer__Access &sipStrings_QtOpenGL[3949]
#define sipNameNr_QOpenGLTextureBlitter 3971
#define sipName_QOpenGLTextureBlitter &sipStrings_QtOpenGL[3971]
#define sipNameNr_QOpenGLVersionProfile 3993
#define sipName_QOpenGLVersionProfile &sipStrings_QtOpenGL[3993]
#define sipNameNr_RGB_BP_UNSIGNED_FLOAT 4015
#define sipName_RGB_BP_UNSIGNED_FLOAT &sipStrings_QtOpenGL[4015]
#define sipNameNr_RangeInvalidateBuffer 4037
#define sipName_RangeInvalidateBuffer &sipStrings_QtOpenGL[4037]
#define sipNameNr_SRGB8_Alpha8_ASTC_4x4 4059
#define sipName_SRGB8_Alpha8_ASTC_4x4 &sipStrings_QtOpenGL[4059]
#define sipNameNr_SRGB8_Alpha8_ASTC_5x4 4081
#define sipName_SRGB8_Alpha8_ASTC_5x4 &sipStrings_QtOpenGL[4081]
#define sipNameNr_SRGB8_Alpha8_ASTC_5x5 4103
#define sipName_SRGB8_Alpha8_ASTC_5x5 &sipStrings_QtOpenGL[4103]
#define sipNameNr_SRGB8_Alpha8_ASTC_6x5 4125
#define sipName_SRGB8_Alpha8_ASTC_6x5 &sipStrings_QtOpenGL[4125]
#define sipNameNr_SRGB8_Alpha8_ASTC_6x6 4147
#define sipName_SRGB8_Alpha8_ASTC_6x6 &sipStrings_QtOpenGL[4147]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x5 4169
#define sipName_SRGB8_Alpha8_ASTC_8x5 &sipStrings_QtOpenGL[4169]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x6 4191
#define sipName_SRGB8_Alpha8_ASTC_8x6 &sipStrings_QtOpenGL[4191]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x8 4213
#define sipName_SRGB8_Alpha8_ASTC_8x8 &sipStrings_QtOpenGL[4213]
#define sipNameNr_SRGB8_Alpha8_ETC2_EAC 4235
#define sipName_SRGB8_Alpha8_ETC2_EAC &sipStrings_QtOpenGL[4235]
#define sipNameNr_UndefinedBehaviorType 4257
#define sipName_UndefinedBehaviorType &sipStrings_QtOpenGL[4257]
#define sipNameNr_bindAttributeLocation 4279
#define sipName_bindAttributeLocation &sipStrings_QtOpenGL[4279]
#define sipNameNr_disableAttributeArray 4301
#define sipName_disableAttributeArray &sipStrings_QtOpenGL[4301]
#define sipNameNr_glActiveShaderProgram 4323
#define sipName_glActiveShaderProgram &sipStrings_QtOpenGL[4323]
#define sipNameNr_glBindProgramPipeline 4345
#define sipName_glBindProgramPipeline &sipStrings_QtOpenGL[4345]
#define sipNameNr_glClientActiveTexture 4367
#define sipName_glClientActiveTexture &sipStrings_QtOpenGL[4367]
#define sipNameNr_glConvolutionFilter1D 4389
#define sipName_glConvolutionFilter1D &sipStrings_QtOpenGL[4389]
#define sipNameNr_glConvolutionFilter2D 4411
#define sipName_glConvolutionFilter2D &sipStrings_QtOpenGL[4411]
#define sipNameNr_glDrawArraysInstanced 4433
#define sipName_glDrawArraysInstanced &sipStrings_QtOpenGL[4433]
#define sipNameNr_glIsTransformFeedback 4455
#define sipName_glIsTransformFeedback &sipStrings_QtOpenGL[4455]
#define sipNameNr_glRenderbufferStorage 4477
#define sipName_glRenderbufferStorage &sipStrings_QtOpenGL[4477]
#define sipNameNr_glStencilFuncSeparate 4499
#define sipName_glStencilFuncSeparate &sipStrings_QtOpenGL[4499]
#define sipNameNr_glStencilMaskSeparate 4521
#define sipName_glStencilMaskSeparate &sipStrings_QtOpenGL[4521]
#define sipNameNr_glUniformBlockBinding 4543
#define sipName_glUniformBlockBinding &sipStrings_QtOpenGL[4543]
#define sipNameNr_glVertexAttribDivisor 4565
#define sipName_glVertexAttribDivisor &sipStrings_QtOpenGL[4565]
#define sipNameNr_glVertexAttribPointer 4587
#define sipName_glVertexAttribPointer &sipStrings_QtOpenGL[4587]
#define sipNameNr_internalTextureFormat 4609
#define sipName_internalTextureFormat &sipStrings_QtOpenGL[4609]
#define sipNameNr_mouseDoubleClickEvent 4631
#define sipName_mouseDoubleClickEvent &sipStrings_QtOpenGL[4631]
#define sipNameNr_setComparisonFunction 4653
#define sipName_setComparisonFunction &sipStrings_QtOpenGL[4653]
#define sipNameNr_setLevelOfDetailRange 4675
#define sipName_setLevelOfDetailRange &sipStrings_QtOpenGL[4675]
#define sipNameNr_setMinificationFilter 4697
#define sipName_setMinificationFilter &sipStrings_QtOpenGL[4697]
#define sipNameNr_AnisotropicFiltering 4719
#define sipName_AnisotropicFiltering &sipStrings_QtOpenGL[4719]
#define sipNameNr_BindingTarget1DArray 4740
#define sipName_BindingTarget1DArray &sipStrings_QtOpenGL[4740]
#define sipNameNr_BindingTarget2DArray 4761
#define sipName_BindingTarget2DArray &sipStrings_QtOpenGL[4761]
#define sipNameNr_BindingTargetCubeMap 4782
#define sipName_BindingTargetCubeMap &sipStrings_QtOpenGL[4782]
#define sipNameNr_CombinedDepthStencil 4803
#define sipName_CombinedDepthStencil &sipStrings_QtOpenGL[4803]
#define sipNameNr_DontResetTextureUnit 4824
#define sipName_DontResetTextureUnit &sipStrings_QtOpenGL[4824]
#define sipNameNr_LuminanceAlphaFormat 4845
#define sipName_LuminanceAlphaFormat &sipStrings_QtOpenGL[4845]
#define sipNameNr_NearestMipMapNearest 4866
#define sipName_NearestMipMapNearest &sipStrings_QtOpenGL[4866]
#define sipNameNr_NotificationSeverity 4887
#define sipName_NotificationSeverity &sipStrings_QtOpenGL[4887]
#define sipNameNr_QOpenGLFunctions_2_0 4908
#define sipName_QOpenGLFunctions_2_0 &sipStrings_QtOpenGL[4908]
#define sipNameNr_QOpenGLFunctions_2_1 4929
#define sipName_QOpenGLFunctions_2_1 &sipStrings_QtOpenGL[4929]
#define sipNameNr_QOpenGLShaderProgram 4950
#define sipName_QOpenGLShaderProgram &sipStrings_QtOpenGL[4950]
#define sipNameNr_ShaderCompilerSource 4971
#define sipName_ShaderCompilerSource &sipStrings_QtOpenGL[4971]
#define sipNameNr_TextureCubeMapArrays 4992
#define sipName_TextureCubeMapArrays &sipStrings_QtOpenGL[4992]
#define sipNameNr_enableAttributeArray 5013
#define sipName_enableAttributeArray &sipStrings_QtOpenGL[5013]
#define sipNameNr_glBindAttribLocation 5034
#define sipName_glBindAttribLocation &sipStrings_QtOpenGL[5034]
#define sipNameNr_glBlendFuncSeparatei 5055
#define sipName_glBlendFuncSeparatei &sipStrings_QtOpenGL[5055]
#define sipNameNr_glDisableClientState 5076
#define sipName_glDisableClientState &sipStrings_QtOpenGL[5076]
#define sipNameNr_glFramebufferTexture 5097
#define sipName_glFramebufferTexture &sipStrings_QtOpenGL[5097]
#define sipNameNr_glGetAttachedShaders 5118
#define sipName_glGetAttachedShaders &sipStrings_QtOpenGL[5118]
#define sipNameNr_glGetUniformLocation 5139
#define sipName_glGetUniformLocation &sipStrings_QtOpenGL[5139]
#define sipNameNr_glSecondaryColor3ubv 5160
#define sipName_glSecondaryColor3ubv &sipStrings_QtOpenGL[5160]
#define sipNameNr_glSecondaryColor3uiv 5181
#define sipName_glSecondaryColor3uiv &sipStrings_QtOpenGL[5181]
#define sipNameNr_glSecondaryColor3usv 5202
#define sipName_glSecondaryColor3usv &sipStrings_QtOpenGL[5202]
#define sipNameNr_maximumLevelOfDetail 5223
#define sipName_maximumLevelOfDetail &sipStrings_QtOpenGL[5223]
#define sipNameNr_maximumMessageLength 5244
#define sipName_maximumMessageLength &sipStrings_QtOpenGL[5244]
#define sipNameNr_minimumLevelOfDetail 5265
#define sipName_minimumLevelOfDetail &sipStrings_QtOpenGL[5265]
#define sipNameNr_setLevelofDetailBias 5286
#define sipName_setLevelofDetailBias &sipStrings_QtOpenGL[5286]
#define sipNameNr_setMaximumAnisotropy 5307
#define sipName_setMaximumAnisotropy &sipStrings_QtOpenGL[5307]
#define sipNameNr_setUniformValueArray 5328
#define sipName_setUniformValueArray &sipStrings_QtOpenGL[5328]
#define sipNameNr_AsynchronousLogging 5349
#define sipName_AsynchronousLogging &sipStrings_QtOpenGL[5349]
#define sipNameNr_BindingTargetBuffer 5369
#define sipName_BindingTargetBuffer &sipStrings_QtOpenGL[5369]
#define sipNameNr_CompareGreaterEqual 5389
#define sipName_CompareGreaterEqual &sipStrings_QtOpenGL[5389]
#define sipNameNr_CompareRefToTexture 5409
#define sipName_CompareRefToTexture &sipStrings_QtOpenGL[5409]
#define sipNameNr_CoordinateDirection 311
#define sipName_CoordinateDirection &sipStrings_QtOpenGL[311]
#define sipNameNr_DontGenerateMipMaps 5429
#define sipName_DontGenerateMipMaps &sipStrings_QtOpenGL[5429]
#define sipNameNr_LinearMipMapNearest 5449
#define sipName_LinearMipMapNearest &sipStrings_QtOpenGL[5449]
#define sipNameNr_NearestMipMapLinear 5469
#define sipName_NearestMipMapLinear &sipStrings_QtOpenGL[5469]
#define sipNameNr_QOpenGLBuffer__Type 5489
#define sipName_QOpenGLBuffer__Type &sipStrings_QtOpenGL[5489]
#define sipNameNr_QOpenGLDebugMessage 5509
#define sipName_QOpenGLDebugMessage &sipStrings_QtOpenGL[5509]
#define sipNameNr_RGB_BP_SIGNED_FLOAT 5529
#define sipName_RGB_BP_SIGNED_FLOAT &sipStrings_QtOpenGL[5529]
#define sipNameNr_RangeUnsynchronized 5549
#define sipName_RangeUnsynchronized &sipStrings_QtOpenGL[5549]
#define sipNameNr_Target2DMultisample 1697
#define sipName_Target2DMultisample &sipStrings_QtOpenGL[1697]
#define sipNameNr_TessellationControl 5569
#define sipName_TessellationControl &sipStrings_QtOpenGL[5569]
#define sipNameNr_glBeginQueryIndexed 5589
#define sipName_glBeginQueryIndexed &sipStrings_QtOpenGL[5589]
#define sipNameNr_glBlendFuncSeparate 5609
#define sipName_glBlendFuncSeparate &sipStrings_QtOpenGL[5609]
#define sipNameNr_glCopyColorSubTable 5629
#define sipName_glCopyColorSubTable &sipStrings_QtOpenGL[5629]
#define sipNameNr_glCopyTexSubImage1D 5649
#define sipName_glCopyTexSubImage1D &sipStrings_QtOpenGL[5649]
#define sipNameNr_glCopyTexSubImage2D 5669
#define sipName_glCopyTexSubImage2D &sipStrings_QtOpenGL[5669]
#define sipNameNr_glCopyTexSubImage3D 5689
#define sipName_glCopyTexSubImage3D &sipStrings_QtOpenGL[5689]
#define sipNameNr_glDepthRangeIndexed 5709
#define sipName_glDepthRangeIndexed &sipStrings_QtOpenGL[5709]
#define sipNameNr_glDrawRangeElements 5729
#define sipName_glDrawRangeElements &sipStrings_QtOpenGL[5729]
#define sipNameNr_glEnableClientState 5749
#define sipName_glEnableClientState &sipStrings_QtOpenGL[5749]
#define sipNameNr_glGetAttribLocation 5769
#define sipName_glGetAttribLocation &sipStrings_QtOpenGL[5769]
#define sipNameNr_glGetProgramInfoLog 5789
#define sipName_glGetProgramInfoLog &sipStrings_QtOpenGL[5789]
#define sipNameNr_glGetTexParameterfv 5809
#define sipName_glGetTexParameterfv &sipStrings_QtOpenGL[5809]
#define sipNameNr_glGetTexParameteriv 5829
#define sipName_glGetTexParameteriv &sipStrings_QtOpenGL[5829]
#define sipNameNr_glGetVertexAttribdv 5849
#define sipName_glGetVertexAttribdv &sipStrings_QtOpenGL[5849]
#define sipNameNr_glGetVertexAttribfv 5869
#define sipName_glGetVertexAttribfv &sipStrings_QtOpenGL[5869]
#define sipNameNr_glGetVertexAttribiv 5889
#define sipName_glGetVertexAttribiv &sipStrings_QtOpenGL[5889]
#define sipNameNr_glIsProgramPipeline 5909
#define sipName_glIsProgramPipeline &sipStrings_QtOpenGL[5909]
#define sipNameNr_glProgramParameteri 5929
#define sipName_glProgramParameteri &sipStrings_QtOpenGL[5929]
#define sipNameNr_glProgramUniform1ui 5949
#define sipName_glProgramUniform1ui &sipStrings_QtOpenGL[5949]
#define sipNameNr_glProgramUniform2ui 5969
#define sipName_glProgramUniform2ui &sipStrings_QtOpenGL[5969]
#define sipNameNr_glProgramUniform3ui 5989
#define sipName_glProgramUniform3ui &sipStrings_QtOpenGL[5989]
#define sipNameNr_glProgramUniform4ui 6009
#define sipName_glProgramUniform4ui &sipStrings_QtOpenGL[6009]
#define sipNameNr_glSamplerParameterf 6029
#define sipName_glSamplerParameterf &sipStrings_QtOpenGL[6029]
#define sipNameNr_glSamplerParameteri 6049
#define sipName_glSamplerParameteri &sipStrings_QtOpenGL[6049]
#define sipNameNr_glSecondaryColor3bv 6069
#define sipName_glSecondaryColor3bv &sipStrings_QtOpenGL[6069]
#define sipNameNr_glSecondaryColor3dv 6089
#define sipName_glSecondaryColor3dv &sipStrings_QtOpenGL[6089]
#define sipNameNr_glSecondaryColor3fv 6109
#define sipName_glSecondaryColor3fv &sipStrings_QtOpenGL[6109]
#define sipNameNr_glSecondaryColor3iv 6129
#define sipName_glSecondaryColor3iv &sipStrings_QtOpenGL[6129]
#define sipNameNr_glSecondaryColor3sv 6149
#define sipName_glSecondaryColor3sv &sipStrings_QtOpenGL[6149]
#define sipNameNr_glSecondaryColor3ub 6169
#define sipName_glSecondaryColor3ub &sipStrings_QtOpenGL[6169]
#define sipNameNr_glSecondaryColor3ui 6189
#define sipName_glSecondaryColor3ui &sipStrings_QtOpenGL[6189]
#define sipNameNr_glSecondaryColor3us 6209
#define sipName_glSecondaryColor3us &sipStrings_QtOpenGL[6209]
#define sipNameNr_glStencilOpSeparate 6229
#define sipName_glStencilOpSeparate &sipStrings_QtOpenGL[6229]
#define sipNameNr_glVertexAttrib4Nubv 6249
#define sipName_glVertexAttrib4Nubv &sipStrings_QtOpenGL[6249]
#define sipNameNr_glVertexAttrib4Nuiv 6269
#define sipName_glVertexAttrib4Nuiv &sipStrings_QtOpenGL[6269]
#define sipNameNr_glVertexAttrib4Nusv 6289
#define sipName_glVertexAttrib4Nusv &sipStrings_QtOpenGL[6289]
#define sipNameNr_magnificationFilter 6309
#define sipName_magnificationFilter &sipStrings_QtOpenGL[6309]
#define sipNameNr_setDepthStencilMode 6329
#define sipName_setDepthStencilMode &sipStrings_QtOpenGL[6329]
#define sipNameNr_setDevicePixelRatio 6349
#define sipName_setDevicePixelRatio &sipStrings_QtOpenGL[6349]
#define sipNameNr_setPatchVertexCount 6369
#define sipName_setPatchVertexCount &sipStrings_QtOpenGL[6369]
#define sipNameNr_setSwapBytesEnabled 6389
#define sipName_setSwapBytesEnabled &sipStrings_QtOpenGL[6389]
#define sipNameNr_ComparisonFunction 347
#define sipName_ComparisonFunction &sipStrings_QtOpenGL[347]
#define sipNameNr_LinearMipMapLinear 6409
#define sipName_LinearMipMapLinear &sipStrings_QtOpenGL[6409]
#define sipNameNr_PartialUpdateBlend 6428
#define sipName_PartialUpdateBlend &sipStrings_QtOpenGL[6428]
#define sipNameNr_QOpenGLDebugLogger 6447
#define sipName_QOpenGLDebugLogger &sipStrings_QtOpenGL[6447]
#define sipNameNr_QOpenGLPaintDevice 6466
#define sipName_QOpenGLPaintDevice &sipStrings_QtOpenGL[6466]
#define sipNameNr_QOpenGLTimeMonitor 6485
#define sipName_QOpenGLTimeMonitor &sipStrings_QtOpenGL[6485]
#define sipNameNr_RangeFlushExplicit 6504
#define sipName_RangeFlushExplicit &sipStrings_QtOpenGL[6504]
#define sipNameNr_SynchronousLogging 6523
#define sipName_SynchronousLogging &sipStrings_QtOpenGL[6523]
#define sipNameNr_TargetCubeMapArray 1886
#define sipName_TargetCubeMapArray &sipStrings_QtOpenGL[1886]
#define sipNameNr_TextureMipMapLevel 6542
#define sipName_TextureMipMapLevel &sipStrings_QtOpenGL[6542]
#define sipNameNr_TextureMultisample 6561
#define sipName_TextureMultisample &sipStrings_QtOpenGL[6561]
#define sipNameNr_UInt32_RGB10A2_Rev 6580
#define sipName_UInt32_RGB10A2_Rev &sipStrings_QtOpenGL[6580]
#define sipNameNr_WindowSystemSource 6599
#define sipName_WindowSystemSource &sipStrings_QtOpenGL[6599]
#define sipNameNr_addColorAttachment 6618
#define sipName_addColorAttachment &sipStrings_QtOpenGL[6618]
#define sipNameNr_comparisonFunction 6637
#define sipName_comparisonFunction &sipStrings_QtOpenGL[6637]
#define sipNameNr_ensureActiveTarget 6656
#define sipName_ensureActiveTarget &sipStrings_QtOpenGL[6656]
#define sipNameNr_glBindRenderbuffer 6675
#define sipName_glBindRenderbuffer &sipStrings_QtOpenGL[6675]
#define sipNameNr_glGetActiveUniform 6694
#define sipName_glGetActiveUniform &sipStrings_QtOpenGL[6694]
#define sipNameNr_glGetShaderInfoLog 6713
#define sipName_glGetShaderInfoLog &sipStrings_QtOpenGL[6713]
#define sipNameNr_glMinSampleShading 6732
#define sipName_glMinSampleShading &sipStrings_QtOpenGL[6732]
#define sipNameNr_glMultiTexCoord1dv 6751
#define sipName_glMultiTexCoord1dv &sipStrings_QtOpenGL[6751]
#define sipNameNr_glMultiTexCoord1fv 6770
#define sipName_glMultiTexCoord1fv &sipStrings_QtOpenGL[6770]
#define sipNameNr_glMultiTexCoord1iv 6789
#define sipName_glMultiTexCoord1iv &sipStrings_QtOpenGL[6789]
#define sipNameNr_glMultiTexCoord1sv 6808
#define sipName_glMultiTexCoord1sv &sipStrings_QtOpenGL[6808]
#define sipNameNr_glMultiTexCoord2dv 6827
#define sipName_glMultiTexCoord2dv &sipStrings_QtOpenGL[6827]
#define sipNameNr_glMultiTexCoord2fv 6846
#define sipName_glMultiTexCoord2fv &sipStrings_QtOpenGL[6846]
#define sipNameNr_glMultiTexCoord2iv 6865
#define sipName_glMultiTexCoord2iv &sipStrings_QtOpenGL[6865]
#define sipNameNr_glMultiTexCoord2sv 6884
#define sipName_glMultiTexCoord2sv &sipStrings_QtOpenGL[6884]
#define sipNameNr_glMultiTexCoord3dv 6903
#define sipName_glMultiTexCoord3dv &sipStrings_QtOpenGL[6903]
#define sipNameNr_glMultiTexCoord3fv 6922
#define sipName_glMultiTexCoord3fv &sipStrings_QtOpenGL[6922]
#define sipNameNr_glMultiTexCoord3iv 6941
#define sipName_glMultiTexCoord3iv &sipStrings_QtOpenGL[6941]
#define sipNameNr_glMultiTexCoord3sv 6960
#define sipName_glMultiTexCoord3sv &sipStrings_QtOpenGL[6960]
#define sipNameNr_glMultiTexCoord4dv 6979
#define sipName_glMultiTexCoord4dv &sipStrings_QtOpenGL[6979]
#define sipNameNr_glMultiTexCoord4fv 6998
#define sipName_glMultiTexCoord4fv &sipStrings_QtOpenGL[6998]
#define sipNameNr_glMultiTexCoord4iv 7017
#define sipName_glMultiTexCoord4iv &sipStrings_QtOpenGL[7017]
#define sipNameNr_glMultiTexCoord4sv 7036
#define sipName_glMultiTexCoord4sv &sipStrings_QtOpenGL[7036]
#define sipNameNr_glPointParameterfv 7055
#define sipName_glPointParameterfv &sipStrings_QtOpenGL[7055]
#define sipNameNr_glPointParameteriv 7074
#define sipName_glPointParameteriv &sipStrings_QtOpenGL[7074]
#define sipNameNr_glProgramUniform1d 7093
#define sipName_glProgramUniform1d &sipStrings_QtOpenGL[7093]
#define sipNameNr_glProgramUniform1f 7112
#define sipName_glProgramUniform1f &sipStrings_QtOpenGL[7112]
#define sipNameNr_glProgramUniform1i 7131
#define sipName_glProgramUniform1i &sipStrings_QtOpenGL[7131]
#define sipNameNr_glProgramUniform2d 7150
#define sipName_glProgramUniform2d &sipStrings_QtOpenGL[7150]
#define sipNameNr_glProgramUniform2f 7169
#define sipName_glProgramUniform2f &sipStrings_QtOpenGL[7169]
#define sipNameNr_glProgramUniform2i 7188
#define sipName_glProgramUniform2i &sipStrings_QtOpenGL[7188]
#define sipNameNr_glProgramUniform3d 7207
#define sipName_glProgramUniform3d &sipStrings_QtOpenGL[7207]
#define sipNameNr_glProgramUniform3f 7226
#define sipName_glProgramUniform3f &sipStrings_QtOpenGL[7226]
#define sipNameNr_glProgramUniform3i 7245
#define sipName_glProgramUniform3i &sipStrings_QtOpenGL[7245]
#define sipNameNr_glProgramUniform4d 7264
#define sipName_glProgramUniform4d &sipStrings_QtOpenGL[7264]
#define sipNameNr_glProgramUniform4f 7283
#define sipName_glProgramUniform4f &sipStrings_QtOpenGL[7283]
#define sipNameNr_glProgramUniform4i 7302
#define sipName_glProgramUniform4i &sipStrings_QtOpenGL[7302]
#define sipNameNr_glPushClientAttrib 7321
#define sipName_glPushClientAttrib &sipStrings_QtOpenGL[7321]
#define sipNameNr_glSecondaryColor3b 7340
#define sipName_glSecondaryColor3b &sipStrings_QtOpenGL[7340]
#define sipNameNr_glSecondaryColor3d 7359
#define sipName_glSecondaryColor3d &sipStrings_QtOpenGL[7359]
#define sipNameNr_glSecondaryColor3f 7378
#define sipName_glSecondaryColor3f &sipStrings_QtOpenGL[7378]
#define sipNameNr_glSecondaryColor3i 7397
#define sipName_glSecondaryColor3i &sipStrings_QtOpenGL[7397]
#define sipNameNr_glSecondaryColor3s 7416
#define sipName_glSecondaryColor3s &sipStrings_QtOpenGL[7416]
#define sipNameNr_glUniformMatrix2fv 7435
#define sipName_glUniformMatrix2fv &sipStrings_QtOpenGL[7435]
#define sipNameNr_glUniformMatrix3fv 7454
#define sipName_glUniformMatrix3fv &sipStrings_QtOpenGL[7454]
#define sipNameNr_glUniformMatrix4fv 7473
#define sipName_glUniformMatrix4fv &sipStrings_QtOpenGL[7473]
#define sipNameNr_glUseProgramStages 7492
#define sipName_glUseProgramStages &sipStrings_QtOpenGL[7492]
#define sipNameNr_glVertexAttrib4Nbv 7511
#define sipName_glVertexAttrib4Nbv &sipStrings_QtOpenGL[7511]
#define sipNameNr_glVertexAttrib4Niv 7530
#define sipName_glVertexAttrib4Niv &sipStrings_QtOpenGL[7530]
#define sipNameNr_glVertexAttrib4Nsv 7549
#define sipName_glVertexAttrib4Nsv &sipStrings_QtOpenGL[7549]
#define sipNameNr_glVertexAttrib4Nub 7568
#define sipName_glVertexAttrib4Nub &sipStrings_QtOpenGL[7568]
#define sipNameNr_glVertexAttrib4ubv 7587
#define sipName_glVertexAttrib4ubv &sipStrings_QtOpenGL[7587]
#define sipNameNr_glVertexAttrib4uiv 7606
#define sipName_glVertexAttrib4uiv &sipStrings_QtOpenGL[7606]
#define sipNameNr_glVertexAttrib4usv 7625
#define sipName_glVertexAttrib4usv &sipStrings_QtOpenGL[7625]
#define sipNameNr_glVertexAttribP1ui 7644
#define sipName_glVertexAttribP1ui &sipStrings_QtOpenGL[7644]
#define sipNameNr_glVertexAttribP2ui 7663
#define sipName_glVertexAttribP2ui &sipStrings_QtOpenGL[7663]
#define sipNameNr_glVertexAttribP3ui 7682
#define sipName_glVertexAttribP3ui &sipStrings_QtOpenGL[7682]
#define sipNameNr_glVertexAttribP4ui 7701
#define sipName_glVertexAttribP4ui &sipStrings_QtOpenGL[7701]
#define sipNameNr_glViewportIndexedf 7720
#define sipName_glViewportIndexedf &sipStrings_QtOpenGL[7720]
#define sipNameNr_isStorageAllocated 7739
#define sipName_isStorageAllocated &sipStrings_QtOpenGL[7739]
#define sipNameNr_isSwapBytesEnabled 7758
#define sipName_isSwapBytesEnabled &sipStrings_QtOpenGL[7758]
#define sipNameNr_levelOfDetailRange 7777
#define sipName_levelOfDetailRange &sipStrings_QtOpenGL[7777]
#define sipNameNr_minificationFilter 7796
#define sipName_minificationFilter &sipStrings_QtOpenGL[7796]
#define sipNameNr_setAttributeBuffer 7815
#define sipName_setAttributeBuffer &sipStrings_QtOpenGL[7815]
#define sipNameNr_ApplicationSource 7834
#define sipName_ApplicationSource &sipStrings_QtOpenGL[7834]
#define sipNameNr_NPOTTextureRepeat 7852
#define sipName_NPOTTextureRepeat &sipStrings_QtOpenGL[7852]
#define sipNameNr_PartialUpdateBlit 7870
#define sipName_PartialUpdateBlit &sipStrings_QtOpenGL[7870]
#define sipNameNr_PixelUnpackBuffer 7888
#define sipName_PixelUnpackBuffer &sipStrings_QtOpenGL[7888]
#define sipNameNr_QOpenGLTimerQuery 7906
#define sipName_QOpenGLTimerQuery &sipStrings_QtOpenGL[7906]
#define sipNameNr_UInt16_R5G6B5_Rev 7924
#define sipName_UInt16_R5G6B5_Rev &sipStrings_QtOpenGL[7924]
#define sipNameNr_UInt16_RGB5A1_Rev 7942
#define sipName_UInt16_RGB5A1_Rev &sipStrings_QtOpenGL[7942]
#define sipNameNr_attributeLocation 7960
#define sipName_attributeLocation &sipStrings_QtOpenGL[7960]
#define sipNameNr_compileSourceCode 7978
#define sipName_compileSourceCode &sipStrings_QtOpenGL[7978]
#define sipNameNr_compileSourceFile 7996
#define sipName_compileSourceFile &sipStrings_QtOpenGL[7996]
#define sipNameNr_createTextureView 8014
#define sipName_createTextureView &sipStrings_QtOpenGL[8014]
#define sipNameNr_glBindFramebuffer 8032
#define sipName_glBindFramebuffer &sipStrings_QtOpenGL[8032]
#define sipNameNr_glBindVertexArray 8050
#define sipName_glBindVertexArray &sipStrings_QtOpenGL[8050]
#define sipNameNr_glBlitFramebuffer 8068
#define sipName_glBlitFramebuffer &sipStrings_QtOpenGL[8068]
#define sipNameNr_glEdgeFlagPointer 8086
#define sipName_glEdgeFlagPointer &sipStrings_QtOpenGL[8086]
#define sipNameNr_glEndQueryIndexed 8104
#define sipName_glEndQueryIndexed &sipStrings_QtOpenGL[8104]
#define sipNameNr_glFogCoordPointer 8122
#define sipName_glFogCoordPointer &sipStrings_QtOpenGL[8122]
#define sipNameNr_glGetActiveAttrib 8140
#define sipName_glGetActiveAttrib &sipStrings_QtOpenGL[8140]
#define sipNameNr_glGetShaderSource 8158
#define sipName_glGetShaderSource &sipStrings_QtOpenGL[8158]
#define sipNameNr_glMultiTexCoord1d 8176
#define sipName_glMultiTexCoord1d &sipStrings_QtOpenGL[8176]
#define sipNameNr_glMultiTexCoord1f 8194
#define sipName_glMultiTexCoord1f &sipStrings_QtOpenGL[8194]
#define sipNameNr_glMultiTexCoord1i 8212
#define sipName_glMultiTexCoord1i &sipStrings_QtOpenGL[8212]
#define sipNameNr_glMultiTexCoord1s 8230
#define sipName_glMultiTexCoord1s &sipStrings_QtOpenGL[8230]
#define sipNameNr_glMultiTexCoord2d 8248
#define sipName_glMultiTexCoord2d &sipStrings_QtOpenGL[8248]
#define sipNameNr_glMultiTexCoord2f 8266
#define sipName_glMultiTexCoord2f &sipStrings_QtOpenGL[8266]
#define sipNameNr_glMultiTexCoord2i 8284
#define sipName_glMultiTexCoord2i &sipStrings_QtOpenGL[8284]
#define sipNameNr_glMultiTexCoord2s 8302
#define sipName_glMultiTexCoord2s &sipStrings_QtOpenGL[8302]
#define sipNameNr_glMultiTexCoord3d 8320
#define sipName_glMultiTexCoord3d &sipStrings_QtOpenGL[8320]
#define sipNameNr_glMultiTexCoord3f 8338
#define sipName_glMultiTexCoord3f &sipStrings_QtOpenGL[8338]
#define sipNameNr_glMultiTexCoord3i 8356
#define sipName_glMultiTexCoord3i &sipStrings_QtOpenGL[8356]
#define sipNameNr_glMultiTexCoord3s 8374
#define sipName_glMultiTexCoord3s &sipStrings_QtOpenGL[8374]
#define sipNameNr_glMultiTexCoord4d 8392
#define sipName_glMultiTexCoord4d &sipStrings_QtOpenGL[8392]
#define sipNameNr_glMultiTexCoord4f 8410
#define sipName_glMultiTexCoord4f &sipStrings_QtOpenGL[8410]
#define sipNameNr_glMultiTexCoord4i 8428
#define sipName_glMultiTexCoord4i &sipStrings_QtOpenGL[8428]
#define sipNameNr_glMultiTexCoord4s 8446
#define sipName_glMultiTexCoord4s &sipStrings_QtOpenGL[8446]
#define sipNameNr_glPatchParameteri 8464
#define sipName_glPatchParameteri &sipStrings_QtOpenGL[8464]
#define sipNameNr_glPointParameterf 8482
#define sipName_glPointParameterf &sipStrings_QtOpenGL[8482]
#define sipNameNr_glPointParameteri 8500
#define sipName_glPointParameteri &sipStrings_QtOpenGL[8500]
#define sipNameNr_glPopClientAttrib 8518
#define sipName_glPopClientAttrib &sipStrings_QtOpenGL[8518]
#define sipNameNr_glProvokingVertex 8536
#define sipName_glProvokingVertex &sipStrings_QtOpenGL[8536]
#define sipNameNr_glTexCoordPointer 8554
#define sipName_glTexCoordPointer &sipStrings_QtOpenGL[8554]
#define sipNameNr_glValidateProgram 8572
#define sipName_glValidateProgram &sipStrings_QtOpenGL[8572]
#define sipNameNr_glVertexAttrib1dv 8590
#define sipName_glVertexAttrib1dv &sipStrings_QtOpenGL[8590]
#define sipNameNr_glVertexAttrib1fv 8608
#define sipName_glVertexAttrib1fv &sipStrings_QtOpenGL[8608]
#define sipNameNr_glVertexAttrib1sv 8626
#define sipName_glVertexAttrib1sv &sipStrings_QtOpenGL[8626]
#define sipNameNr_glVertexAttrib2dv 8644
#define sipName_glVertexAttrib2dv &sipStrings_QtOpenGL[8644]
#define sipNameNr_glVertexAttrib2fv 8662
#define sipName_glVertexAttrib2fv &sipStrings_QtOpenGL[8662]
#define sipNameNr_glVertexAttrib2sv 8680
#define sipName_glVertexAttrib2sv &sipStrings_QtOpenGL[8680]
#define sipNameNr_glVertexAttrib3dv 8698
#define sipName_glVertexAttrib3dv &sipStrings_QtOpenGL[8698]
#define sipNameNr_glVertexAttrib3fv 8716
#define sipName_glVertexAttrib3fv &sipStrings_QtOpenGL[8716]
#define sipNameNr_glVertexAttrib3sv 8734
#define sipName_glVertexAttrib3sv &sipStrings_QtOpenGL[8734]
#define sipNameNr_glVertexAttrib4bv 8752
#define sipName_glVertexAttrib4bv &sipStrings_QtOpenGL[8752]
#define sipNameNr_glVertexAttrib4dv 8770
#define sipName_glVertexAttrib4dv &sipStrings_QtOpenGL[8770]
#define sipNameNr_glVertexAttrib4fv 8788
#define sipName_glVertexAttrib4fv &sipStrings_QtOpenGL[8788]
#define sipNameNr_glVertexAttrib4iv 8806
#define sipName_glVertexAttrib4iv &sipStrings_QtOpenGL[8806]
#define sipNameNr_glVertexAttrib4sv 8824
#define sipName_glVertexAttrib4sv &sipStrings_QtOpenGL[8824]
#define sipNameNr_glVertexAttribL1d 8842
#define sipName_glVertexAttribL1d &sipStrings_QtOpenGL[8842]
#define sipNameNr_glVertexAttribL2d 8860
#define sipName_glVertexAttribL2d &sipStrings_QtOpenGL[8860]
#define sipNameNr_glVertexAttribL3d 8878
#define sipName_glVertexAttribL3d &sipStrings_QtOpenGL[8878]
#define sipNameNr_glVertexAttribL4d 8896
#define sipName_glVertexAttribL4d &sipStrings_QtOpenGL[8896]
#define sipNameNr_isResultAvailable 8914
#define sipName_isResultAvailable &sipStrings_QtOpenGL[8914]
#define sipNameNr_levelofDetailBias 8932
#define sipName_levelofDetailBias &sipStrings_QtOpenGL[8932]
#define sipNameNr_maximumAnisotropy 8950
#define sipName_maximumAnisotropy &sipStrings_QtOpenGL[8950]
#define sipNameNr_mouseReleaseEvent 8968
#define sipName_mouseReleaseEvent &sipStrings_QtOpenGL[8968]
#define sipNameNr_setAttributeArray 8986
#define sipName_setAttributeArray &sipStrings_QtOpenGL[8986]
#define sipNameNr_setAttributeValue 9004
#define sipName_setAttributeValue &sipStrings_QtOpenGL[9004]
#define sipNameNr_setComparisonMode 9022
#define sipName_setComparisonMode &sipStrings_QtOpenGL[9022]
#define sipNameNr_setCompressedData 9040
#define sipName_setCompressedData &sipStrings_QtOpenGL[9040]
#define sipNameNr_setRedBlueSwizzle 9058
#define sipName_setRedBlueSwizzle &sipStrings_QtOpenGL[9058]
#define sipNameNr_CommpareNotEqual 9076
#define sipName_CommpareNotEqual &sipStrings_QtOpenGL[9076]
#define sipNameNr_CompareLessEqual 9093
#define sipName_CompareLessEqual &sipStrings_QtOpenGL[9093]
#define sipNameNr_CubeMapNegativeX 9110
#define sipName_CubeMapNegativeX &sipStrings_QtOpenGL[9110]
#define sipNameNr_CubeMapNegativeY 9127
#define sipName_CubeMapNegativeY &sipStrings_QtOpenGL[9127]
#define sipNameNr_CubeMapNegativeZ 9144
#define sipName_CubeMapNegativeZ &sipStrings_QtOpenGL[9144]
#define sipNameNr_CubeMapPositiveX 9161
#define sipName_CubeMapPositiveX &sipStrings_QtOpenGL[9161]
#define sipNameNr_CubeMapPositiveY 9178
#define sipName_CubeMapPositiveY &sipStrings_QtOpenGL[9178]
#define sipNameNr_CubeMapPositiveZ 9195
#define sipName_CubeMapPositiveZ &sipStrings_QtOpenGL[9195]
#define sipNameNr_DepthStencilMode 519
#define sipName_DepthStencilMode &sipStrings_QtOpenGL[519]
#define sipNameNr_ImmutableStorage 9212
#define sipName_ImmutableStorage &sipStrings_QtOpenGL[9212]
#define sipNameNr_MipMapGeneration 552
#define sipName_MipMapGeneration &sipStrings_QtOpenGL[552]
#define sipNameNr_OriginBottomLeft 9229
#define sipName_OriginBottomLeft &sipStrings_QtOpenGL[9229]
#define sipNameNr_ResetTextureUnit 4828
#define sipName_ResetTextureUnit &sipStrings_QtOpenGL[4828]
#define sipNameNr_StencilTexturing 9246
#define sipName_StencilTexturing &sipStrings_QtOpenGL[9246]
#define sipNameNr_SwizzleComponent 585
#define sipName_SwizzleComponent &sipStrings_QtOpenGL[585]
#define sipNameNr_TextureRectangle 9263
#define sipName_TextureRectangle &sipStrings_QtOpenGL[9263]
#define sipNameNr_TextureUnitReset 618
#define sipName_TextureUnitReset &sipStrings_QtOpenGL[618]
#define sipNameNr_ThirdPartySource 9280
#define sipName_ThirdPartySource &sipStrings_QtOpenGL[9280]
#define sipNameNr_UInt16_RGBA4_Rev 9297
#define sipName_UInt16_RGBA4_Rev &sipStrings_QtOpenGL[9297]
#define sipNameNr_UInt32_RGBA8_Rev 9314
#define sipName_UInt32_RGBA8_Rev &sipStrings_QtOpenGL[9314]
#define sipNameNr_depthStencilMode 9331
#define sipName_depthStencilMode &sipStrings_QtOpenGL[9331]
#define sipNameNr_disconnectNotify 9348
#define sipName_disconnectNotify &sipStrings_QtOpenGL[9348]
#define sipNameNr_glBindBufferBase 9365
#define sipName_glBindBufferBase &sipStrings_QtOpenGL[9365]
#define sipNameNr_glBlendEquationi 9382
#define sipName_glBlendEquationi &sipStrings_QtOpenGL[9382]
#define sipNameNr_glCopyColorTable 9399
#define sipName_glCopyColorTable &sipStrings_QtOpenGL[9399]
#define sipNameNr_glCopyTexImage1D 9416
#define sipName_glCopyTexImage1D &sipStrings_QtOpenGL[9416]
#define sipNameNr_glCopyTexImage2D 9433
#define sipName_glCopyTexImage2D &sipStrings_QtOpenGL[9433]
#define sipNameNr_glDeleteTextures 9450
#define sipName_glDeleteTextures &sipStrings_QtOpenGL[9450]
#define sipNameNr_glGenerateMipmap 9467
#define sipName_glGenerateMipmap &sipStrings_QtOpenGL[9467]
#define sipNameNr_glIsRenderbuffer 9484
#define sipName_glIsRenderbuffer &sipStrings_QtOpenGL[9484]
#define sipNameNr_glPixelTransferf 9501
#define sipName_glPixelTransferf &sipStrings_QtOpenGL[9501]
#define sipNameNr_glPixelTransferi 9518
#define sipName_glPixelTransferi &sipStrings_QtOpenGL[9518]
#define sipNameNr_glPolygonStipple 9535
#define sipName_glPolygonStipple &sipStrings_QtOpenGL[9535]
#define sipNameNr_glResetHistogram 9552
#define sipName_glResetHistogram &sipStrings_QtOpenGL[9552]
#define sipNameNr_glSampleCoverage 9569
#define sipName_glSampleCoverage &sipStrings_QtOpenGL[9569]
#define sipNameNr_glScissorIndexed 9586
#define sipName_glScissorIndexed &sipStrings_QtOpenGL[9586]
#define sipNameNr_glTexParameterfv 9603
#define sipName_glTexParameterfv &sipStrings_QtOpenGL[9603]
#define sipNameNr_glTexParameteriv 9620
#define sipName_glTexParameteriv &sipStrings_QtOpenGL[9620]
#define sipNameNr_glVertexAttrib1d 9637
#define sipName_glVertexAttrib1d &sipStrings_QtOpenGL[9637]
#define sipNameNr_glVertexAttrib1f 9654
#define sipName_glVertexAttrib1f &sipStrings_QtOpenGL[9654]
#define sipNameNr_glVertexAttrib1s 9671
#define sipName_glVertexAttrib1s &sipStrings_QtOpenGL[9671]
#define sipNameNr_glVertexAttrib2d 9688
#define sipName_glVertexAttrib2d &sipStrings_QtOpenGL[9688]
#define sipNameNr_glVertexAttrib2f 9705
#define sipName_glVertexAttrib2f &sipStrings_QtOpenGL[9705]
#define sipNameNr_glVertexAttrib2s 9722
#define sipName_glVertexAttrib2s &sipStrings_QtOpenGL[9722]
#define sipNameNr_glVertexAttrib3d 9739
#define sipName_glVertexAttrib3d &sipStrings_QtOpenGL[9739]
#define sipNameNr_glVertexAttrib3f 9756
#define sipName_glVertexAttrib3f &sipStrings_QtOpenGL[9756]
#define sipNameNr_glVertexAttrib3s 9773
#define sipName_glVertexAttrib3s &sipStrings_QtOpenGL[9773]
#define sipNameNr_glVertexAttrib4d 9790
#define sipName_glVertexAttrib4d &sipStrings_QtOpenGL[9790]
#define sipNameNr_glVertexAttrib4f 9807
#define sipName_glVertexAttrib4f &sipStrings_QtOpenGL[9807]
#define sipNameNr_glVertexAttrib4s 9824
#define sipName_glVertexAttrib4s &sipStrings_QtOpenGL[9824]
#define sipNameNr_hasOpenGLShaders 9841
#define sipName_hasOpenGLShaders &sipStrings_QtOpenGL[9841]
#define sipNameNr_maximumMipLevels 9858
#define sipName_maximumMipLevels &sipStrings_QtOpenGL[9858]
#define sipNameNr_patchVertexCount 9875
#define sipName_patchVertexCount &sipStrings_QtOpenGL[9875]
#define sipNameNr_removeAllShaders 9892
#define sipName_removeAllShaders &sipStrings_QtOpenGL[9892]
#define sipNameNr_setDotsPerMeterX 9909
#define sipName_setDotsPerMeterX &sipStrings_QtOpenGL[9909]
#define sipNameNr_setDotsPerMeterY 9926
#define sipName_setDotsPerMeterY &sipStrings_QtOpenGL[9926]
#define sipNameNr_setMinMagFilters 9943
#define sipName_setMinMagFilters &sipStrings_QtOpenGL[9943]
#define sipNameNr_setMipLevelRange 9960
#define sipName_setMipLevelRange &sipStrings_QtOpenGL[9960]
#define sipNameNr_setTextureTarget 9977
#define sipName_setTextureTarget &sipStrings_QtOpenGL[9977]
#define sipNameNr_waitForIntervals 9994
#define sipName_waitForIntervals &sipStrings_QtOpenGL[9994]
#define sipNameNr_waitForTimestamp 10011
#define sipName_waitForTimestamp &sipStrings_QtOpenGL[10011]
#define sipNameNr_BindingTarget1D 10028
#define sipName_BindingTarget1D &sipStrings_QtOpenGL[10028]
#define sipNameNr_BindingTarget2D 10044
#define sipName_BindingTarget2D &sipStrings_QtOpenGL[10044]
#define sipNameNr_BindingTarget3D 10060
#define sipName_BindingTarget3D &sipStrings_QtOpenGL[10060]
#define sipNameNr_CompareNotEqual 10076
#define sipName_CompareNotEqual &sipStrings_QtOpenGL[10076]
#define sipNameNr_GenerateMipMaps 5433
#define sipName_GenerateMipMaps &sipStrings_QtOpenGL[5433]
#define sipNameNr_InvalidSeverity 10092
#define sipName_InvalidSeverity &sipStrings_QtOpenGL[10092]
#define sipNameNr_LuminanceFormat 10108
#define sipName_LuminanceFormat &sipStrings_QtOpenGL[10108]
#define sipNameNr_NoPartialUpdate 10124
#define sipName_NoPartialUpdate &sipStrings_QtOpenGL[10124]
#define sipNameNr_PerformanceType 10140
#define sipName_PerformanceType &sipStrings_QtOpenGL[10140]
#define sipNameNr_PixelPackBuffer 10156
#define sipName_PixelPackBuffer &sipStrings_QtOpenGL[10156]
#define sipNameNr_PortabilityType 10172
#define sipName_PortabilityType &sipStrings_QtOpenGL[10172]
#define sipNameNr_10188 10188
#define sipName_10188 &sipStrings_QtOpenGL[10188]
#define sipNameNr_RGBA_ASTC_10x10 10204
#define sipName_RGBA_ASTC_10x10 &sipStrings_QtOpenGL[10204]
#define sipNameNr_RGBA_ASTC_12x10 10220
#define sipName_RGBA_ASTC_12x10 &sipStrings_QtOpenGL[10220]
#define sipNameNr_RGBA_ASTC_12x12 10236
#define sipName_RGBA_ASTC_12x12 &sipStrings_QtOpenGL[10236]
#define sipNameNr_RangeAccessFlag 878
#define sipName_RangeAccessFlag &sipStrings_QtOpenGL[878]
#define sipNameNr_RangeInvalidate 10252
#define sipName_RangeInvalidate &sipStrings_QtOpenGL[10252]
#define sipNameNr_SRGB_Alpha_DXT1 10268
#define sipName_SRGB_Alpha_DXT1 &sipStrings_QtOpenGL[10268]
#define sipNameNr_SRGB_Alpha_DXT3 10284
#define sipName_SRGB_Alpha_DXT3 &sipStrings_QtOpenGL[10284]
#define sipNameNr_SRGB_Alpha_DXT5 10300
#define sipName_SRGB_Alpha_DXT5 &sipStrings_QtOpenGL[10300]
#define sipNameNr_TargetRectangle 3405
#define sipName_TargetRectangle &sipStrings_QtOpenGL[3405]
#define sipNameNr_UInt32_RG11B10F 10316
#define sipName_UInt32_RG11B10F &sipStrings_QtOpenGL[10316]
#define sipNameNr_UInt8_RG3B2_Rev 10332
#define sipName_UInt8_RG3B2_Rev &sipStrings_QtOpenGL[10332]
#define sipNameNr_allocateStorage 10348
#define sipName_allocateStorage &sipStrings_QtOpenGL[10348]
#define sipNameNr_blitFramebuffer 10364
#define sipName_blitFramebuffer &sipStrings_QtOpenGL[10364]
#define sipNameNr_disableMessages 10380
#define sipName_disableMessages &sipStrings_QtOpenGL[10380]
#define sipNameNr_generateMipMaps 10396
#define sipName_generateMipMaps &sipStrings_QtOpenGL[10396]
#define sipNameNr_glActiveTexture 10412
#define sipName_glActiveTexture &sipStrings_QtOpenGL[10412]
#define sipNameNr_glBlendEquation 10428
#define sipName_glBlendEquation &sipStrings_QtOpenGL[10428]
#define sipNameNr_glBufferSubData 10444
#define sipName_glBufferSubData &sipStrings_QtOpenGL[10444]
#define sipNameNr_glClearBufferfi 10460
#define sipName_glClearBufferfi &sipStrings_QtOpenGL[10460]
#define sipNameNr_glColorMaterial 10476
#define sipName_glColorMaterial &sipStrings_QtOpenGL[10476]
#define sipNameNr_glColorSubTable 10492
#define sipName_glColorSubTable &sipStrings_QtOpenGL[10492]
#define sipNameNr_glCompileShader 10508
#define sipName_glCompileShader &sipStrings_QtOpenGL[10508]
#define sipNameNr_glCreateProgram 10524
#define sipName_glCreateProgram &sipStrings_QtOpenGL[10524]
#define sipNameNr_glDeleteBuffers 10540
#define sipName_glDeleteBuffers &sipStrings_QtOpenGL[10540]
#define sipNameNr_glDeleteProgram 10556
#define sipName_glDeleteProgram &sipStrings_QtOpenGL[10556]
#define sipNameNr_glDeleteQueries 10572
#define sipName_glDeleteQueries &sipStrings_QtOpenGL[10572]
#define sipNameNr_glGetMaterialfv 10588
#define sipName_glGetMaterialfv &sipStrings_QtOpenGL[10588]
#define sipNameNr_glGetMaterialiv 10604
#define sipName_glGetMaterialiv &sipStrings_QtOpenGL[10604]
#define sipNameNr_glIsFramebuffer 10620
#define sipName_glIsFramebuffer &sipStrings_QtOpenGL[10620]
#define sipNameNr_glIsVertexArray 10636
#define sipName_glIsVertexArray &sipStrings_QtOpenGL[10636]
#define sipNameNr_glNormalPointer 10652
#define sipName_glNormalPointer &sipStrings_QtOpenGL[10652]
#define sipNameNr_glPolygonOffset 10668
#define sipName_glPolygonOffset &sipStrings_QtOpenGL[10668]
#define sipNameNr_glTexParameterf 10684
#define sipName_glTexParameterf &sipStrings_QtOpenGL[10684]
#define sipNameNr_glTexParameteri 10700
#define sipName_glTexParameteri &sipStrings_QtOpenGL[10700]
#define sipNameNr_glTexSubImage1D 10716
#define sipName_glTexSubImage1D &sipStrings_QtOpenGL[10716]
#define sipNameNr_glTexSubImage2D 10732
#define sipName_glTexSubImage2D &sipStrings_QtOpenGL[10732]
#define sipNameNr_glTexSubImage3D 10748
#define sipName_glTexSubImage3D &sipStrings_QtOpenGL[10748]
#define sipNameNr_glVertexPointer 10764
#define sipName_glVertexPointer &sipStrings_QtOpenGL[10764]
#define sipNameNr_grabFramebuffer 10780
#define sipName_grabFramebuffer &sipStrings_QtOpenGL[10780]
#define sipNameNr_internal_format 10796
#define sipName_internal_format &sipStrings_QtOpenGL[10796]
#define sipNameNr_isLegacyVersion 10812
#define sipName_isLegacyVersion &sipStrings_QtOpenGL[10812]
#define sipNameNr_keyReleaseEvent 10828
#define sipName_keyReleaseEvent &sipStrings_QtOpenGL[10828]
#define sipNameNr_mousePressEvent 10844
#define sipName_mousePressEvent &sipStrings_QtOpenGL[10844]
#define sipNameNr_recordTimestamp 10860
#define sipName_recordTimestamp &sipStrings_QtOpenGL[10860]
#define sipNameNr_setMipBaseLevel 10876
#define sipName_setMipBaseLevel &sipStrings_QtOpenGL[10876]
#define sipNameNr_setPaintFlipped 10892
#define sipName_setPaintFlipped &sipStrings_QtOpenGL[10892]
#define sipNameNr_setUniformValue 10908
#define sipName_setUniformValue &sipStrings_QtOpenGL[10908]
#define sipNameNr_setUsagePattern 10924
#define sipName_setUsagePattern &sipStrings_QtOpenGL[10924]
#define sipNameNr_sourceTransform 10940
#define sipName_sourceTransform &sipStrings_QtOpenGL[10940]
#define sipNameNr_targetTransform 10956
#define sipName_targetTransform &sipStrings_QtOpenGL[10956]
#define sipNameNr_uniformLocation 10972
#define sipName_uniformLocation &sipStrings_QtOpenGL[10972]
#define sipNameNr_CompareGreater 10988
#define sipName_CompareGreater &sipStrings_QtOpenGL[10988]
#define sipNameNr_ComparisonMode 941
#define sipName_ComparisonMode &sipStrings_QtOpenGL[941]
#define sipNameNr_LuminanceAlpha 11003
#define sipName_LuminanceAlpha &sipStrings_QtOpenGL[11003]
#define sipNameNr_MediumSeverity 11018
#define sipName_MediumSeverity &sipStrings_QtOpenGL[11018]
#define sipNameNr_MirroredRepeat 11033
#define sipName_MirroredRepeat &sipStrings_QtOpenGL[11033]
#define sipNameNr_NoSourceFormat 11048
#define sipName_NoSourceFormat &sipStrings_QtOpenGL[11048]
#define sipNameNr_PyQt6_QtOpenGL 11063
#define sipName_PyQt6_QtOpenGL &sipStrings_QtOpenGL[11063]
#define sipNameNr_QOpenGLTexture 11078
#define sipName_QOpenGLTexture &sipStrings_QtOpenGL[11078]
#define sipNameNr_RG11_EAC_SNorm 11093
#define sipName_RG11_EAC_SNorm &sipStrings_QtOpenGL[11093]
#define sipNameNr_RG11_EAC_UNorm 11108
#define sipName_RG11_EAC_UNorm &sipStrings_QtOpenGL[11108]
#define sipNameNr_RGBA8_ETC2_EAC 11123
#define sipName_RGBA8_ETC2_EAC &sipStrings_QtOpenGL[11123]
#define sipNameNr_RGBA_ASTC_10x5 11138
#define sipName_RGBA_ASTC_10x5 &sipStrings_QtOpenGL[11138]
#define sipNameNr_RGBA_ASTC_10x6 11153
#define sipName_RGBA_ASTC_10x6 &sipStrings_QtOpenGL[11153]
#define sipNameNr_RGBA_ASTC_10x8 11168
#define sipName_RGBA_ASTC_10x8 &sipStrings_QtOpenGL[11168]
#define sipNameNr_RG_ATI2N_SNorm 11183
#define sipName_RG_ATI2N_SNorm &sipStrings_QtOpenGL[11183]
#define sipNameNr_RG_ATI2N_UNorm 11198
#define sipName_RG_ATI2N_UNorm &sipStrings_QtOpenGL[11198]
#define sipNameNr_UInt32_RGB10A2 11213
#define sipName_UInt32_RGB10A2 &sipStrings_QtOpenGL[11213]
#define sipNameNr_UInt32_RGB9_E5 11228
#define sipName_UInt32_RGB9_E5 &sipStrings_QtOpenGL[11228]
#define sipNameNr_UpdateBehavior 1276
#define sipName_UpdateBehavior &sipStrings_QtOpenGL[1276]
#define sipNameNr_boundTextureId 11243
#define sipName_boundTextureId &sipStrings_QtOpenGL[11243]
#define sipNameNr_comparisonMode 11258
#define sipName_comparisonMode &sipStrings_QtOpenGL[11258]
#define sipNameNr_enableMessages 11273
#define sipName_enableMessages &sipStrings_QtOpenGL[11273]
#define sipNameNr_glArrayElement 11288
#define sipName_glArrayElement &sipStrings_QtOpenGL[11288]
#define sipNameNr_glAttachShader 11303
#define sipName_glAttachShader &sipStrings_QtOpenGL[11303]
#define sipNameNr_glClearStencil 11318
#define sipName_glClearStencil &sipStrings_QtOpenGL[11318]
#define sipNameNr_glColorPointer 11333
#define sipName_glColorPointer &sipStrings_QtOpenGL[11333]
#define sipNameNr_glCreateShader 11348
#define sipName_glCreateShader &sipStrings_QtOpenGL[11348]
#define sipNameNr_glDeleteShader 11363
#define sipName_glDeleteShader &sipStrings_QtOpenGL[11363]
#define sipNameNr_glDetachShader 11378
#define sipName_glDetachShader &sipStrings_QtOpenGL[11378]
#define sipNameNr_glDrawElements 11393
#define sipName_glDrawElements &sipStrings_QtOpenGL[11393]
#define sipNameNr_glEvalCoord1dv 11408
#define sipName_glEvalCoord1dv &sipStrings_QtOpenGL[11408]
#define sipNameNr_glEvalCoord1fv 11423
#define sipName_glEvalCoord1fv &sipStrings_QtOpenGL[11423]
#define sipNameNr_glEvalCoord2dv 11438
#define sipName_glEvalCoord2dv &sipStrings_QtOpenGL[11438]
#define sipNameNr_glEvalCoord2fv 11453
#define sipName_glEvalCoord2fv &sipStrings_QtOpenGL[11453]
#define sipNameNr_glGetClipPlane 11468
#define sipName_glGetClipPlane &sipStrings_QtOpenGL[11468]
#define sipNameNr_glGetProgramiv 11483
#define sipName_glGetProgramiv &sipStrings_QtOpenGL[11483]
#define sipNameNr_glIndexPointer 11498
#define sipName_glIndexPointer &sipStrings_QtOpenGL[11498]
#define sipNameNr_glLightModelfv 11513
#define sipName_glLightModelfv &sipStrings_QtOpenGL[11513]
#define sipNameNr_glLightModeliv 11528
#define sipName_glLightModeliv &sipStrings_QtOpenGL[11528]
#define sipNameNr_glLoadIdentity 11543
#define sipName_glLoadIdentity &sipStrings_QtOpenGL[11543]
#define sipNameNr_glQueryCounter 11558
#define sipName_glQueryCounter &sipStrings_QtOpenGL[11558]
#define sipNameNr_glRasterPos2dv 11573
#define sipName_glRasterPos2dv &sipStrings_QtOpenGL[11573]
#define sipNameNr_glRasterPos2fv 11588
#define sipName_glRasterPos2fv &sipStrings_QtOpenGL[11588]
#define sipNameNr_glRasterPos2iv 11603
#define sipName_glRasterPos2iv &sipStrings_QtOpenGL[11603]
#define sipNameNr_glRasterPos2sv 11618
#define sipName_glRasterPos2sv &sipStrings_QtOpenGL[11618]
#define sipNameNr_glRasterPos3dv 11633
#define sipName_glRasterPos3dv &sipStrings_QtOpenGL[11633]
#define sipNameNr_glRasterPos3fv 11648
#define sipName_glRasterPos3fv &sipStrings_QtOpenGL[11648]
#define sipNameNr_glRasterPos3iv 11663
#define sipName_glRasterPos3iv &sipStrings_QtOpenGL[11663]
#define sipNameNr_glRasterPos3sv 11678
#define sipName_glRasterPos3sv &sipStrings_QtOpenGL[11678]
#define sipNameNr_glRasterPos4dv 11693
#define sipName_glRasterPos4dv &sipStrings_QtOpenGL[11693]
#define sipNameNr_glRasterPos4fv 11708
#define sipName_glRasterPos4fv &sipStrings_QtOpenGL[11708]
#define sipNameNr_glRasterPos4iv 11723
#define sipName_glRasterPos4iv &sipStrings_QtOpenGL[11723]
#define sipNameNr_glRasterPos4sv 11738
#define sipName_glRasterPos4sv &sipStrings_QtOpenGL[11738]
#define sipNameNr_glWindowPos2dv 11753
#define sipName_glWindowPos2dv &sipStrings_QtOpenGL[11753]
#define sipNameNr_glWindowPos2fv 11768
#define sipName_glWindowPos2fv &sipStrings_QtOpenGL[11768]
#define sipNameNr_glWindowPos2iv 11783
#define sipName_glWindowPos2iv &sipStrings_QtOpenGL[11783]
#define sipNameNr_glWindowPos2sv 11798
#define sipName_glWindowPos2sv &sipStrings_QtOpenGL[11798]
#define sipNameNr_glWindowPos3dv 11813
#define sipName_glWindowPos3dv &sipStrings_QtOpenGL[11813]
#define sipNameNr_glWindowPos3fv 11828
#define sipName_glWindowPos3fv &sipStrings_QtOpenGL[11828]
#define sipNameNr_glWindowPos3iv 11843
#define sipName_glWindowPos3iv &sipStrings_QtOpenGL[11843]
#define sipNameNr_glWindowPos3sv 11858
#define sipName_glWindowPos3sv &sipStrings_QtOpenGL[11858]
#define sipNameNr_loggedMessages 11873
#define sipName_loggedMessages &sipStrings_QtOpenGL[11873]
#define sipNameNr_mouseMoveEvent 11888
#define sipName_mouseMoveEvent &sipStrings_QtOpenGL[11888]
#define sipNameNr_resetBaseLevel 11903
#define sipName_resetBaseLevel &sipStrings_QtOpenGL[11903]
#define sipNameNr_setBorderColor 11918
#define sipName_setBorderColor &sipStrings_QtOpenGL[11918]
#define sipNameNr_setImageHeight 11933
#define sipName_setImageHeight &sipStrings_QtOpenGL[11933]
#define sipNameNr_setMipMaxLevel 11948
#define sipName_setMipMaxLevel &sipStrings_QtOpenGL[11948]
#define sipNameNr_setSampleCount 11963
#define sipName_setSampleCount &sipStrings_QtOpenGL[11963]
#define sipNameNr_setSwizzleMask 11978
#define sipName_setSwizzleMask &sipStrings_QtOpenGL[11978]
#define sipNameNr_updateBehavior 11993
#define sipName_updateBehavior &sipStrings_QtOpenGL[11993]
#define sipNameNr_versionProfile 12008
#define sipName_versionProfile &sipStrings_QtOpenGL[12008]
#define sipNameNr_waitForSamples 12023
#define sipName_waitForSamples &sipStrings_QtOpenGL[12023]
#define sipNameNr_BindingTarget 1187
#define sipName_BindingTarget &sipStrings_QtOpenGL[1187]
#define sipNameNr_ClampToBorder 12038
#define sipName_ClampToBorder &sipStrings_QtOpenGL[12038]
#define sipNameNr_CompareAlways 12052
#define sipName_CompareAlways &sipStrings_QtOpenGL[12052]
#define sipNameNr_GroupPushType 12066
#define sipName_GroupPushType &sipStrings_QtOpenGL[12066]
#define sipNameNr_InvalidSource 12080
#define sipName_InvalidSource &sipStrings_QtOpenGL[12080]
#define sipNameNr_OriginTopLeft 12094
#define sipName_OriginTopLeft &sipStrings_QtOpenGL[12094]
#define sipNameNr_QOpenGLBuffer 12108
#define sipName_QOpenGLBuffer &sipStrings_QtOpenGL[12108]
#define sipNameNr_QOpenGLShader 12122
#define sipName_QOpenGLShader &sipStrings_QtOpenGL[12122]
#define sipNameNr_QOpenGLWindow 12136
#define sipName_QOpenGLWindow &sipStrings_QtOpenGL[12136]
#define sipNameNr_R11_EAC_SNorm 12150
#define sipName_R11_EAC_SNorm &sipStrings_QtOpenGL[12150]
#define sipNameNr_R11_EAC_UNorm 12164
#define sipName_R11_EAC_UNorm &sipStrings_QtOpenGL[12164]
#define sipNameNr_RGBA_ASTC_4x4 12178
#define sipName_RGBA_ASTC_4x4 &sipStrings_QtOpenGL[12178]
#define sipNameNr_RGBA_ASTC_5x4 12192
#define sipName_RGBA_ASTC_5x4 &sipStrings_QtOpenGL[12192]
#define sipNameNr_RGBA_ASTC_5x5 12206
#define sipName_RGBA_ASTC_5x5 &sipStrings_QtOpenGL[12206]
#define sipNameNr_RGBA_ASTC_6x5 12220
#define sipName_RGBA_ASTC_6x5 &sipStrings_QtOpenGL[12220]
#define sipNameNr_RGBA_ASTC_6x6 12234
#define sipName_RGBA_ASTC_6x6 &sipStrings_QtOpenGL[12234]
#define sipNameNr_RGBA_ASTC_8x5 12248
#define sipName_RGBA_ASTC_8x5 &sipStrings_QtOpenGL[12248]
#define sipNameNr_RGBA_ASTC_8x6 12262
#define sipName_RGBA_ASTC_8x6 &sipStrings_QtOpenGL[12262]
#define sipNameNr_RGBA_ASTC_8x8 12276
#define sipName_RGBA_ASTC_8x8 &sipStrings_QtOpenGL[12276]
#define sipNameNr_R_ATI1N_SNorm 12290
#define sipName_R_ATI1N_SNorm &sipStrings_QtOpenGL[12290]
#define sipNameNr_R_ATI1N_UNorm 12304
#define sipName_R_ATI1N_UNorm &sipStrings_QtOpenGL[12304]
#define sipNameNr_SRGB_BP_UNorm 12318
#define sipName_SRGB_BP_UNorm &sipStrings_QtOpenGL[12318]
#define sipNameNr_ShaderTypeBit 1366
#define sipName_ShaderTypeBit &sipStrings_QtOpenGL[1366]
#define sipNameNr_Target1DArray 4747
#define sipName_Target1DArray &sipStrings_QtOpenGL[4747]
#define sipNameNr_Target2DArray 4768
#define sipName_Target2DArray &sipStrings_QtOpenGL[4768]
#define sipNameNr_TargetCubeMap 4789
#define sipName_TargetCubeMap &sipStrings_QtOpenGL[4789]
#define sipNameNr_TextureArrays 12332
#define sipName_TextureArrays &sipStrings_QtOpenGL[12332]
#define sipNameNr_TextureBuffer 12346
#define sipName_TextureBuffer &sipStrings_QtOpenGL[12346]
#define sipNameNr_TextureFormat 1217
#define sipName_TextureFormat &sipStrings_QtOpenGL[1217]
#define sipNameNr_UInt16_R5G6B5 12360
#define sipName_UInt16_R5G6B5 &sipStrings_QtOpenGL[12360]
#define sipNameNr_UInt16_RGB5A1 12374
#define sipName_UInt16_RGB5A1 &sipStrings_QtOpenGL[12374]
#define sipNameNr_connectNotify 9351
#define sipName_connectNotify &sipStrings_QtOpenGL[9351]
#define sipNameNr_dotsPerMeterX 12388
#define sipName_dotsPerMeterX &sipStrings_QtOpenGL[12388]
#define sipNameNr_dotsPerMeterY 12402
#define sipName_dotsPerMeterY &sipStrings_QtOpenGL[12402]
#define sipNameNr_focusOutEvent 12416
#define sipName_focusOutEvent &sipStrings_QtOpenGL[12416]
#define sipNameNr_glBindSampler 12430
#define sipName_glBindSampler &sipStrings_QtOpenGL[12430]
#define sipNameNr_glBindTexture 12444
#define sipName_glBindTexture &sipStrings_QtOpenGL[12444]
#define sipNameNr_glClearDepthf 12458
#define sipName_glClearDepthf &sipStrings_QtOpenGL[12458]
#define sipNameNr_glDeleteLists 12472
#define sipName_glDeleteLists &sipStrings_QtOpenGL[12472]
#define sipNameNr_glDepthRangef 12486
#define sipName_glDepthRangef &sipStrings_QtOpenGL[12486]
#define sipNameNr_glDrawBuffers 12500
#define sipName_glDrawBuffers &sipStrings_QtOpenGL[12500]
#define sipNameNr_glEvalCoord1d 12514
#define sipName_glEvalCoord1d &sipStrings_QtOpenGL[12514]
#define sipNameNr_glEvalCoord1f 12528
#define sipName_glEvalCoord1f &sipStrings_QtOpenGL[12528]
#define sipNameNr_glEvalCoord2d 12542
#define sipName_glEvalCoord2d &sipStrings_QtOpenGL[12542]
#define sipNameNr_glEvalCoord2f 12556
#define sipName_glEvalCoord2f &sipStrings_QtOpenGL[12556]
#define sipNameNr_glGenTextures 12570
#define sipName_glGenTextures &sipStrings_QtOpenGL[12570]
#define sipNameNr_glGetBooleanv 12584
#define sipName_glGetBooleanv &sipStrings_QtOpenGL[12584]
#define sipNameNr_glGetIntegerv 12598
#define sipName_glGetIntegerv &sipStrings_QtOpenGL[12598]
#define sipNameNr_glGetShaderiv 12612
#define sipName_glGetShaderiv &sipStrings_QtOpenGL[12612]
#define sipNameNr_glGetTexEnvfv 12626
#define sipName_glGetTexEnvfv &sipStrings_QtOpenGL[12626]
#define sipNameNr_glGetTexEnviv 12640
#define sipName_glGetTexEnviv &sipStrings_QtOpenGL[12640]
#define sipNameNr_glGetTexGendv 12654
#define sipName_glGetTexGendv &sipStrings_QtOpenGL[12654]
#define sipNameNr_glGetTexGenfv 12668
#define sipName_glGetTexGenfv &sipStrings_QtOpenGL[12668]
#define sipNameNr_glGetTexGeniv 12682
#define sipName_glGetTexGeniv &sipStrings_QtOpenGL[12682]
#define sipNameNr_glLightModelf 12696
#define sipName_glLightModelf &sipStrings_QtOpenGL[12696]
#define sipNameNr_glLightModeli 12710
#define sipName_glLightModeli &sipStrings_QtOpenGL[12710]
#define sipNameNr_glLineStipple 12724
#define sipName_glLineStipple &sipStrings_QtOpenGL[12724]
#define sipNameNr_glLinkProgram 12738
#define sipName_glLinkProgram &sipStrings_QtOpenGL[12738]
#define sipNameNr_glLoadMatrixd 12752
#define sipName_glLoadMatrixd &sipStrings_QtOpenGL[12752]
#define sipNameNr_glLoadMatrixf 12766
#define sipName_glLoadMatrixf &sipStrings_QtOpenGL[12766]
#define sipNameNr_glMultMatrixd 12780
#define sipName_glMultMatrixd &sipStrings_QtOpenGL[12780]
#define sipNameNr_glMultMatrixf 12794
#define sipName_glMultMatrixf &sipStrings_QtOpenGL[12794]
#define sipNameNr_glPassThrough 12808
#define sipName_glPassThrough &sipStrings_QtOpenGL[12808]
#define sipNameNr_glPixelMapuiv 12822
#define sipName_glPixelMapuiv &sipStrings_QtOpenGL[12822]
#define sipNameNr_glPixelMapusv 12836
#define sipName_glPixelMapusv &sipStrings_QtOpenGL[12836]
#define sipNameNr_glPixelStoref 12850
#define sipName_glPixelStoref &sipStrings_QtOpenGL[12850]
#define sipNameNr_glPixelStorei 12864
#define sipName_glPixelStorei &sipStrings_QtOpenGL[12864]
#define sipNameNr_glPolygonMode 12878
#define sipName_glPolygonMode &sipStrings_QtOpenGL[12878]
#define sipNameNr_glRasterPos2d 12892
#define sipName_glRasterPos2d &sipStrings_QtOpenGL[12892]
#define sipNameNr_glRasterPos2f 12906
#define sipName_glRasterPos2f &sipStrings_QtOpenGL[12906]
#define sipNameNr_glRasterPos2i 12920
#define sipName_glRasterPos2i &sipStrings_QtOpenGL[12920]
#define sipNameNr_glRasterPos2s 12934
#define sipName_glRasterPos2s &sipStrings_QtOpenGL[12934]
#define sipNameNr_glRasterPos3d 12948
#define sipName_glRasterPos3d &sipStrings_QtOpenGL[12948]
#define sipNameNr_glRasterPos3f 12962
#define sipName_glRasterPos3f &sipStrings_QtOpenGL[12962]
#define sipNameNr_glRasterPos3i 12976
#define sipName_glRasterPos3i &sipStrings_QtOpenGL[12976]
#define sipNameNr_glRasterPos3s 12990
#define sipName_glRasterPos3s &sipStrings_QtOpenGL[12990]
#define sipNameNr_glRasterPos4d 13004
#define sipName_glRasterPos4d &sipStrings_QtOpenGL[13004]
#define sipNameNr_glRasterPos4f 13018
#define sipName_glRasterPos4f &sipStrings_QtOpenGL[13018]
#define sipNameNr_glRasterPos4i 13032
#define sipName_glRasterPos4i &sipStrings_QtOpenGL[13032]
#define sipNameNr_glRasterPos4s 13046
#define sipName_glRasterPos4s &sipStrings_QtOpenGL[13046]
#define sipNameNr_glResetMinmax 13060
#define sipName_glResetMinmax &sipStrings_QtOpenGL[13060]
#define sipNameNr_glSampleMaski 13074
#define sipName_glSampleMaski &sipStrings_QtOpenGL[13074]
#define sipNameNr_glStencilFunc 13088
#define sipName_glStencilFunc &sipStrings_QtOpenGL[13088]
#define sipNameNr_glStencilMask 13102
#define sipName_glStencilMask &sipStrings_QtOpenGL[13102]
#define sipNameNr_glTexCoord1dv 13116
#define sipName_glTexCoord1dv &sipStrings_QtOpenGL[13116]
#define sipNameNr_glTexCoord1fv 13130
#define sipName_glTexCoord1fv &sipStrings_QtOpenGL[13130]
#define sipNameNr_glTexCoord1iv 13144
#define sipName_glTexCoord1iv &sipStrings_QtOpenGL[13144]
#define sipNameNr_glTexCoord1sv 13158
#define sipName_glTexCoord1sv &sipStrings_QtOpenGL[13158]
#define sipNameNr_glTexCoord2dv 13172
#define sipName_glTexCoord2dv &sipStrings_QtOpenGL[13172]
#define sipNameNr_glTexCoord2fv 13186
#define sipName_glTexCoord2fv &sipStrings_QtOpenGL[13186]
#define sipNameNr_glTexCoord2iv 13200
#define sipName_glTexCoord2iv &sipStrings_QtOpenGL[13200]
#define sipNameNr_glTexCoord2sv 13214
#define sipName_glTexCoord2sv &sipStrings_QtOpenGL[13214]
#define sipNameNr_glTexCoord3dv 13228
#define sipName_glTexCoord3dv &sipStrings_QtOpenGL[13228]
#define sipNameNr_glTexCoord3fv 13242
#define sipName_glTexCoord3fv &sipStrings_QtOpenGL[13242]
#define sipNameNr_glTexCoord3iv 13256
#define sipName_glTexCoord3iv &sipStrings_QtOpenGL[13256]
#define sipNameNr_glTexCoord3sv 13270
#define sipName_glTexCoord3sv &sipStrings_QtOpenGL[13270]
#define sipNameNr_glTexCoord4dv 13284
#define sipName_glTexCoord4dv &sipStrings_QtOpenGL[13284]
#define sipNameNr_glTexCoord4fv 13298
#define sipName_glTexCoord4fv &sipStrings_QtOpenGL[13298]
#define sipNameNr_glTexCoord4iv 13312
#define sipName_glTexCoord4iv &sipStrings_QtOpenGL[13312]
#define sipNameNr_glTexCoord4sv 13326
#define sipName_glTexCoord4sv &sipStrings_QtOpenGL[13326]
#define sipNameNr_glUnmapBuffer 13340
#define sipName_glUnmapBuffer &sipStrings_QtOpenGL[13340]
#define sipNameNr_glWindowPos2d 13354
#define sipName_glWindowPos2d &sipStrings_QtOpenGL[13354]
#define sipNameNr_glWindowPos2f 13368
#define sipName_glWindowPos2f &sipStrings_QtOpenGL[13368]
#define sipNameNr_glWindowPos2i 13382
#define sipName_glWindowPos2i &sipStrings_QtOpenGL[13382]
#define sipNameNr_glWindowPos2s 13396
#define sipName_glWindowPos2s &sipStrings_QtOpenGL[13396]
#define sipNameNr_glWindowPos3d 13410
#define sipName_glWindowPos3d &sipStrings_QtOpenGL[13410]
#define sipNameNr_glWindowPos3f 13424
#define sipName_glWindowPos3f &sipStrings_QtOpenGL[13424]
#define sipNameNr_glWindowPos3i 13438
#define sipName_glWindowPos3i &sipStrings_QtOpenGL[13438]
#define sipNameNr_glWindowPos3s 13452
#define sipName_glWindowPos3s &sipStrings_QtOpenGL[13452]
#define sipNameNr_isTextureView 13466
#define sipName_isTextureView &sipStrings_QtOpenGL[13466]
#define sipNameNr_keyPressEvent 13480
#define sipName_keyPressEvent &sipStrings_QtOpenGL[13480]
#define sipNameNr_messageLogged 13494
#define sipName_messageLogged &sipStrings_QtOpenGL[13494]
#define sipNameNr_minMagFilters 13508
#define sipName_minMagFilters &sipStrings_QtOpenGL[13508]
#define sipNameNr_mipLevelRange 13522
#define sipName_mipLevelRange &sipStrings_QtOpenGL[13522]
#define sipNameNr_setAttachment 13536
#define sipName_setAttachment &sipStrings_QtOpenGL[13536]
#define sipNameNr_setSkipImages 13550
#define sipName_setSkipImages &sipStrings_QtOpenGL[13550]
#define sipNameNr_setSkipPixels 13564
#define sipName_setSkipPixels &sipStrings_QtOpenGL[13564]
#define sipNameNr_textureTarget 13578
#define sipName_textureTarget &sipStrings_QtOpenGL[13578]
#define sipNameNr_waitForResult 13592
#define sipName_waitForResult &sipStrings_QtOpenGL[13592]
#define sipNameNr_BGRA_Integer 13606
#define sipName_BGRA_Integer &sipStrings_QtOpenGL[13606]
#define sipNameNr_CompareEqual 13619
#define sipName_CompareEqual &sipStrings_QtOpenGL[13619]
#define sipNameNr_CompareNever 13632
#define sipName_CompareNever &sipStrings_QtOpenGL[13632]
#define sipNameNr_DepthStencil 4811
#define sipName_DepthStencil &sipStrings_QtOpenGL[4811]
#define sipNameNr_GroupPopType 13645
#define sipName_GroupPopType &sipStrings_QtOpenGL[13645]
#define sipNameNr_HighSeverity 13658
#define sipName_HighSeverity &sipStrings_QtOpenGL[13658]
#define sipNameNr_NPOTTextures 13671
#define sipName_NPOTTextures &sipStrings_QtOpenGL[13671]
#define sipNameNr_NoAttachment 13684
#define sipName_NoAttachment &sipStrings_QtOpenGL[13684]
#define sipNameNr_RGBA16_SNorm 13697
#define sipName_RGBA16_SNorm &sipStrings_QtOpenGL[13697]
#define sipNameNr_RGBA16_UNorm 13710
#define sipName_RGBA16_UNorm &sipStrings_QtOpenGL[13710]
#define sipNameNr_RGBA_Integer 13723
#define sipName_RGBA_Integer &sipStrings_QtOpenGL[13723]
#define sipNameNr_RGB_BP_UNorm 12319
#define sipName_RGB_BP_UNorm &sipStrings_QtOpenGL[12319]
#define sipNameNr_SRGB8_Alpha8 13736
#define sipName_SRGB8_Alpha8 &sipStrings_QtOpenGL[13736]
#define sipNameNr_SwizzleAlpha 13749
#define sipName_SwizzleAlpha &sipStrings_QtOpenGL[13749]
#define sipNameNr_SwizzleGreen 13762
#define sipName_SwizzleGreen &sipStrings_QtOpenGL[13762]
#define sipNameNr_SwizzleValue 1396
#define sipName_SwizzleValue &sipStrings_QtOpenGL[1396]
#define sipNameNr_TargetBuffer 5376
#define sipName_TargetBuffer &sipStrings_QtOpenGL[5376]
#define sipNameNr_UInt16_RGBA4 13775
#define sipName_UInt16_RGBA4 &sipStrings_QtOpenGL[13775]
#define sipNameNr_UInt32_D24S8 13788
#define sipName_UInt32_D24S8 &sipStrings_QtOpenGL[13788]
#define sipNameNr_UInt32_RGBA8 13801
#define sipName_UInt32_RGBA8 &sipStrings_QtOpenGL[13801]
#define sipNameNr_UsagePattern 1481
#define sipName_UsagePattern &sipStrings_QtOpenGL[1481]
#define sipNameNr_VertexBuffer 13814
#define sipName_VertexBuffer &sipStrings_QtOpenGL[13814]
#define sipNameNr_focusInEvent 13827
#define sipName_focusInEvent &sipStrings_QtOpenGL[13827]
#define sipNameNr_frameSwapped 13840
#define sipName_frameSwapped &sipStrings_QtOpenGL[13840]
#define sipNameNr_glBeginQuery 13853
#define sipName_glBeginQuery &sipStrings_QtOpenGL[13853]
#define sipNameNr_glBindBuffer 13866
#define sipName_glBindBuffer &sipStrings_QtOpenGL[13866]
#define sipNameNr_glBlendColor 13879
#define sipName_glBlendColor &sipStrings_QtOpenGL[13879]
#define sipNameNr_glBlendFunci 13892
#define sipName_glBlendFunci &sipStrings_QtOpenGL[13892]
#define sipNameNr_glBufferData 13905
#define sipName_glBufferData &sipStrings_QtOpenGL[13905]
#define sipNameNr_glClampColor 13918
#define sipName_glClampColor &sipStrings_QtOpenGL[13918]
#define sipNameNr_glClearAccum 13931
#define sipName_glClearAccum &sipStrings_QtOpenGL[13931]
#define sipNameNr_glClearColor 13944
#define sipName_glClearColor &sipStrings_QtOpenGL[13944]
#define sipNameNr_glClearDepth 13957
#define sipName_glClearDepth &sipStrings_QtOpenGL[13957]
#define sipNameNr_glClearIndex 13970
#define sipName_glClearIndex &sipStrings_QtOpenGL[13970]
#define sipNameNr_glColorMaski 13983
#define sipName_glColorMaski &sipStrings_QtOpenGL[13983]
#define sipNameNr_glColorTable 13996
#define sipName_glColorTable &sipStrings_QtOpenGL[13996]
#define sipNameNr_glCopyPixels 14009
#define sipName_glCopyPixels &sipStrings_QtOpenGL[14009]
#define sipNameNr_glDepthRange 14022
#define sipName_glDepthRange &sipStrings_QtOpenGL[14022]
#define sipNameNr_glDrawArrays 14035
#define sipName_glDrawArrays &sipStrings_QtOpenGL[14035]
#define sipNameNr_glDrawBuffer 14048
#define sipName_glDrawBuffer &sipStrings_QtOpenGL[14048]
#define sipNameNr_glDrawPixels 14061
#define sipName_glDrawPixels &sipStrings_QtOpenGL[14061]
#define sipNameNr_glEvalPoint1 14074
#define sipName_glEvalPoint1 &sipStrings_QtOpenGL[14074]
#define sipNameNr_glEvalPoint2 14087
#define sipName_glEvalPoint2 &sipStrings_QtOpenGL[14087]
#define sipNameNr_glFogCoorddv 14100
#define sipName_glFogCoorddv &sipStrings_QtOpenGL[14100]
#define sipNameNr_glFogCoordfv 14113
#define sipName_glFogCoordfv &sipStrings_QtOpenGL[14113]
#define sipNameNr_glGenBuffers 14126
#define sipName_glGenBuffers &sipStrings_QtOpenGL[14126]
#define sipNameNr_glGenQueries 14139
#define sipName_glGenQueries &sipStrings_QtOpenGL[14139]
#define sipNameNr_glGetDoublev 14152
#define sipName_glGetDoublev &sipStrings_QtOpenGL[14152]
#define sipNameNr_glGetLightfv 14165
#define sipName_glGetLightfv &sipStrings_QtOpenGL[14165]
#define sipNameNr_glGetLightiv 14178
#define sipName_glGetLightiv &sipStrings_QtOpenGL[14178]
#define sipNameNr_glGetQueryiv 14191
#define sipName_glGetQueryiv &sipStrings_QtOpenGL[14191]
#define sipNameNr_glIsEnabledi 14204
#define sipName_glIsEnabledi &sipStrings_QtOpenGL[14204]
#define sipNameNr_glMaterialfv 14217
#define sipName_glMaterialfv &sipStrings_QtOpenGL[14217]
#define sipNameNr_glMaterialiv 14230
#define sipName_glMaterialiv &sipStrings_QtOpenGL[14230]
#define sipNameNr_glMatrixMode 14243
#define sipName_glMatrixMode &sipStrings_QtOpenGL[14243]
#define sipNameNr_glPixelMapfv 14256
#define sipName_glPixelMapfv &sipStrings_QtOpenGL[14256]
#define sipNameNr_glPushAttrib 14269
#define sipName_glPushAttrib &sipStrings_QtOpenGL[14269]
#define sipNameNr_glPushMatrix 14282
#define sipName_glPushMatrix &sipStrings_QtOpenGL[14282]
#define sipNameNr_glReadBuffer 14295
#define sipName_glReadBuffer &sipStrings_QtOpenGL[14295]
#define sipNameNr_glReadPixels 14308
#define sipName_glReadPixels &sipStrings_QtOpenGL[14308]
#define sipNameNr_glRenderMode 14321
#define sipName_glRenderMode &sipStrings_QtOpenGL[14321]
#define sipNameNr_glShadeModel 14334
#define sipName_glShadeModel &sipStrings_QtOpenGL[14334]
#define sipNameNr_glTexCoord1d 14347
#define sipName_glTexCoord1d &sipStrings_QtOpenGL[14347]
#define sipNameNr_glTexCoord1f 14360
#define sipName_glTexCoord1f &sipStrings_QtOpenGL[14360]
#define sipNameNr_glTexCoord1i 14373
#define sipName_glTexCoord1i &sipStrings_QtOpenGL[14373]
#define sipNameNr_glTexCoord1s 14386
#define sipName_glTexCoord1s &sipStrings_QtOpenGL[14386]
#define sipNameNr_glTexCoord2d 14399
#define sipName_glTexCoord2d &sipStrings_QtOpenGL[14399]
#define sipNameNr_glTexCoord2f 14412
#define sipName_glTexCoord2f &sipStrings_QtOpenGL[14412]
#define sipNameNr_glTexCoord2i 14425
#define sipName_glTexCoord2i &sipStrings_QtOpenGL[14425]
#define sipNameNr_glTexCoord2s 14438
#define sipName_glTexCoord2s &sipStrings_QtOpenGL[14438]
#define sipNameNr_glTexCoord3d 14451
#define sipName_glTexCoord3d &sipStrings_QtOpenGL[14451]
#define sipNameNr_glTexCoord3f 14464
#define sipName_glTexCoord3f &sipStrings_QtOpenGL[14464]
#define sipNameNr_glTexCoord3i 14477
#define sipName_glTexCoord3i &sipStrings_QtOpenGL[14477]
#define sipNameNr_glTexCoord3s 14490
#define sipName_glTexCoord3s &sipStrings_QtOpenGL[14490]
#define sipNameNr_glTexCoord4d 14503
#define sipName_glTexCoord4d &sipStrings_QtOpenGL[14503]
#define sipNameNr_glTexCoord4f 14516
#define sipName_glTexCoord4f &sipStrings_QtOpenGL[14516]
#define sipNameNr_glTexCoord4i 14529
#define sipName_glTexCoord4i &sipStrings_QtOpenGL[14529]
#define sipNameNr_glTexCoord4s 14542
#define sipName_glTexCoord4s &sipStrings_QtOpenGL[14542]
#define sipNameNr_glTexImage1D 14555
#define sipName_glTexImage1D &sipStrings_QtOpenGL[14555]
#define sipNameNr_glTexImage2D 14568
#define sipName_glTexImage2D &sipStrings_QtOpenGL[14568]
#define sipNameNr_glTexImage3D 14581
#define sipName_glTexImage3D &sipStrings_QtOpenGL[14581]
#define sipNameNr_glTranslated 14594
#define sipName_glTranslated &sipStrings_QtOpenGL[14594]
#define sipNameNr_glTranslatef 14607
#define sipName_glTranslatef &sipStrings_QtOpenGL[14607]
#define sipNameNr_glUniform1fv 14620
#define sipName_glUniform1fv &sipStrings_QtOpenGL[14620]
#define sipNameNr_glUniform1iv 14633
#define sipName_glUniform1iv &sipStrings_QtOpenGL[14633]
#define sipNameNr_glUniform1ui 14646
#define sipName_glUniform1ui &sipStrings_QtOpenGL[14646]
#define sipNameNr_glUniform2fv 14659
#define sipName_glUniform2fv &sipStrings_QtOpenGL[14659]
#define sipNameNr_glUniform2iv 14672
#define sipName_glUniform2iv &sipStrings_QtOpenGL[14672]
#define sipNameNr_glUniform2ui 14685
#define sipName_glUniform2ui &sipStrings_QtOpenGL[14685]
#define sipNameNr_glUniform3fv 14698
#define sipName_glUniform3fv &sipStrings_QtOpenGL[14698]
#define sipNameNr_glUniform3iv 14711
#define sipName_glUniform3iv &sipStrings_QtOpenGL[14711]
#define sipNameNr_glUniform3ui 14724
#define sipName_glUniform3ui &sipStrings_QtOpenGL[14724]
#define sipNameNr_glUniform4fv 14737
#define sipName_glUniform4fv &sipStrings_QtOpenGL[14737]
#define sipNameNr_glUniform4iv 14750
#define sipName_glUniform4iv &sipStrings_QtOpenGL[14750]
#define sipNameNr_glUniform4ui 14763
#define sipName_glUniform4ui &sipStrings_QtOpenGL[14763]
#define sipNameNr_glUseProgram 14776
#define sipName_glUseProgram &sipStrings_QtOpenGL[14776]
#define sipNameNr_initializeGL 14789
#define sipName_initializeGL &sipStrings_QtOpenGL[14789]
#define sipNameNr_mipBaseLevel 14802
#define sipName_mipBaseLevel &sipStrings_QtOpenGL[14802]
#define sipNameNr_paintFlipped 14815
#define sipName_paintFlipped &sipStrings_QtOpenGL[14815]
#define sipNameNr_paintUnderGL 14828
#define sipName_paintUnderGL &sipStrings_QtOpenGL[14828]
#define sipNameNr_recordSample 14841
#define sipName_recordSample &sipStrings_QtOpenGL[14841]
#define sipNameNr_removeShader 14854
#define sipName_removeShader &sipStrings_QtOpenGL[14854]
#define sipNameNr_setAlignment 14867
#define sipName_setAlignment &sipStrings_QtOpenGL[14867]
#define sipNameNr_setMipLevels 14880
#define sipName_setMipLevels &sipStrings_QtOpenGL[14880]
#define sipNameNr_setRowLength 14893
#define sipName_setRowLength &sipStrings_QtOpenGL[14893]
#define sipNameNr_shareContext 14906
#define sipName_shareContext &sipStrings_QtOpenGL[14906]
#define sipNameNr_startLogging 14919
#define sipName_startLogging &sipStrings_QtOpenGL[14919]
#define sipNameNr_usagePattern 14932
#define sipName_usagePattern &sipStrings_QtOpenGL[14932]
#define sipNameNr_AlphaFormat 4854
#define sipName_AlphaFormat &sipStrings_QtOpenGL[4854]
#define sipNameNr_AnySeverity 14945
#define sipName_AnySeverity &sipStrings_QtOpenGL[14945]
#define sipNameNr_BGR_Integer 14957
#define sipName_BGR_Integer &sipStrings_QtOpenGL[14957]
#define sipNameNr_ClampToEdge 14969
#define sipName_ClampToEdge &sipStrings_QtOpenGL[14969]
#define sipNameNr_CompareLess 14981
#define sipName_CompareLess &sipStrings_QtOpenGL[14981]
#define sipNameNr_CompareNone 14993
#define sipName_CompareNone &sipStrings_QtOpenGL[14993]
#define sipNameNr_CubeMapFace 1566
#define sipName_CubeMapFace &sipStrings_QtOpenGL[1566]
#define sipNameNr_DepthFormat 15005
#define sipName_DepthFormat &sipStrings_QtOpenGL[15005]
#define sipNameNr_DynamicCopy 15017
#define sipName_DynamicCopy &sipStrings_QtOpenGL[15017]
#define sipNameNr_DynamicDraw 15029
#define sipName_DynamicDraw &sipStrings_QtOpenGL[15029]
#define sipNameNr_DynamicRead 15041
#define sipName_DynamicRead &sipStrings_QtOpenGL[15041]
#define sipNameNr_IndexBuffer 15053
#define sipName_IndexBuffer &sipStrings_QtOpenGL[15053]
#define sipNameNr_InvalidType 15065
#define sipName_InvalidType &sipStrings_QtOpenGL[15065]
#define sipNameNr_LoggingMode 851
#define sipName_LoggingMode &sipStrings_QtOpenGL[851]
#define sipNameNr_LowSeverity 15077
#define sipName_LowSeverity &sipStrings_QtOpenGL[15077]
#define sipNameNr_NoPixelType 15089
#define sipName_NoPixelType &sipStrings_QtOpenGL[15089]
#define sipNameNr_OtherSource 15101
#define sipName_OtherSource &sipStrings_QtOpenGL[15101]
#define sipNameNr_PixelFormat 1594
#define sipName_PixelFormat &sipStrings_QtOpenGL[1594]
#define sipNameNr_RGB16_SNorm 15113
#define sipName_RGB16_SNorm &sipStrings_QtOpenGL[15113]
#define sipNameNr_RGB16_UNorm 15125
#define sipName_RGB16_UNorm &sipStrings_QtOpenGL[15125]
#define sipNameNr_RGBA8_SNorm 15137
#define sipName_RGBA8_SNorm &sipStrings_QtOpenGL[15137]
#define sipNameNr_RGBA8_UNorm 15149
#define sipName_RGBA8_UNorm &sipStrings_QtOpenGL[15149]
#define sipNameNr_RGB_Integer 15161
#define sipName_RGB_Integer &sipStrings_QtOpenGL[15161]
#define sipNameNr_Red_Integer 15173
#define sipName_Red_Integer &sipStrings_QtOpenGL[15173]
#define sipNameNr_StencilMode 524
#define sipName_StencilMode &sipStrings_QtOpenGL[524]
#define sipNameNr_SwizzleBlue 15185
#define sipName_SwizzleBlue &sipStrings_QtOpenGL[15185]
#define sipNameNr_UInt8_RG3B2 15197
#define sipName_UInt8_RG3B2 &sipStrings_QtOpenGL[15197]
#define sipNameNr_bindDefault 15209
#define sipName_bindDefault &sipStrings_QtOpenGL[15209]
#define sipNameNr_borderColor 15221
#define sipName_borderColor &sipStrings_QtOpenGL[15221]
#define sipNameNr_customEvent 15233
#define sipName_customEvent &sipStrings_QtOpenGL[15233]
#define sipNameNr_doneCurrent 15245
#define sipName_doneCurrent &sipStrings_QtOpenGL[15245]
#define sipNameNr_eventFilter 15257
#define sipName_eventFilter &sipStrings_QtOpenGL[15257]
#define sipNameNr_exposeEvent 15269
#define sipName_exposeEvent &sipStrings_QtOpenGL[15269]
#define sipNameNr_focusObject 15281
#define sipName_focusObject &sipStrings_QtOpenGL[15281]
#define sipNameNr_glAlphaFunc 15293
#define sipName_glAlphaFunc &sipStrings_QtOpenGL[15293]
#define sipNameNr_glBlendFunc 15305
#define sipName_glBlendFunc &sipStrings_QtOpenGL[15305]
#define sipNameNr_glClipPlane 15317
#define sipName_glClipPlane &sipStrings_QtOpenGL[15317]
#define sipNameNr_glColor3ubv 15329
#define sipName_glColor3ubv &sipStrings_QtOpenGL[15329]
#define sipNameNr_glColor3uiv 15341
#define sipName_glColor3uiv &sipStrings_QtOpenGL[15341]
#define sipNameNr_glColor3usv 15353
#define sipName_glColor3usv &sipStrings_QtOpenGL[15353]
#define sipNameNr_glColor4ubv 15365
#define sipName_glColor4ubv &sipStrings_QtOpenGL[15365]
#define sipNameNr_glColor4uiv 15377
#define sipName_glColor4uiv &sipStrings_QtOpenGL[15377]
#define sipNameNr_glColor4usv 15389
#define sipName_glColor4usv &sipStrings_QtOpenGL[15389]
#define sipNameNr_glColorMask 15401
#define sipName_glColorMask &sipStrings_QtOpenGL[15401]
#define sipNameNr_glDepthFunc 15413
#define sipName_glDepthFunc &sipStrings_QtOpenGL[15413]
#define sipNameNr_glDepthMask 15425
#define sipName_glDepthMask &sipStrings_QtOpenGL[15425]
#define sipNameNr_glEdgeFlagv 15437
#define sipName_glEdgeFlagv &sipStrings_QtOpenGL[15437]
#define sipNameNr_glEvalMesh1 15449
#define sipName_glEvalMesh1 &sipStrings_QtOpenGL[15449]
#define sipNameNr_glEvalMesh2 15461
#define sipName_glEvalMesh2 &sipStrings_QtOpenGL[15461]
#define sipNameNr_glFogCoordd 15473
#define sipName_glFogCoordd &sipStrings_QtOpenGL[15473]
#define sipNameNr_glFogCoordf 15485
#define sipName_glFogCoordf &sipStrings_QtOpenGL[15485]
#define sipNameNr_glFrontFace 15497
#define sipName_glFrontFace &sipStrings_QtOpenGL[15497]
#define sipNameNr_glGetFloatv 15509
#define sipName_glGetFloatv &sipStrings_QtOpenGL[15509]
#define sipNameNr_glGetString 15521
#define sipName_glGetString &sipStrings_QtOpenGL[15521]
#define sipNameNr_glHistogram 15533
#define sipName_glHistogram &sipStrings_QtOpenGL[15533]
#define sipNameNr_glIndexMask 15545
#define sipName_glIndexMask &sipStrings_QtOpenGL[15545]
#define sipNameNr_glInitNames 15557
#define sipName_glInitNames &sipStrings_QtOpenGL[15557]
#define sipNameNr_glIsEnabled 15569
#define sipName_glIsEnabled &sipStrings_QtOpenGL[15569]
#define sipNameNr_glIsProgram 15581
#define sipName_glIsProgram &sipStrings_QtOpenGL[15581]
#define sipNameNr_glIsSampler 15593
#define sipName_glIsSampler &sipStrings_QtOpenGL[15593]
#define sipNameNr_glIsTexture 15605
#define sipName_glIsTexture &sipStrings_QtOpenGL[15605]
#define sipNameNr_glLineWidth 15617
#define sipName_glLineWidth &sipStrings_QtOpenGL[15617]
#define sipNameNr_glMapGrid1d 15629
#define sipName_glMapGrid1d &sipStrings_QtOpenGL[15629]
#define sipNameNr_glMapGrid1f 15641
#define sipName_glMapGrid1f &sipStrings_QtOpenGL[15641]
#define sipNameNr_glMapGrid2d 15653
#define sipName_glMapGrid2d &sipStrings_QtOpenGL[15653]
#define sipNameNr_glMapGrid2f 15665
#define sipName_glMapGrid2f &sipStrings_QtOpenGL[15665]
#define sipNameNr_glMaterialf 15677
#define sipName_glMaterialf &sipStrings_QtOpenGL[15677]
#define sipNameNr_glMateriali 15689
#define sipName_glMateriali &sipStrings_QtOpenGL[15689]
#define sipNameNr_glNormal3bv 15701
#define sipName_glNormal3bv &sipStrings_QtOpenGL[15701]
#define sipNameNr_glNormal3dv 15713
#define sipName_glNormal3dv &sipStrings_QtOpenGL[15713]
#define sipNameNr_glNormal3fv 15725
#define sipName_glNormal3fv &sipStrings_QtOpenGL[15725]
#define sipNameNr_glNormal3iv 15737
#define sipName_glNormal3iv &sipStrings_QtOpenGL[15737]
#define sipNameNr_glNormal3sv 15749
#define sipName_glNormal3sv &sipStrings_QtOpenGL[15749]
#define sipNameNr_glPixelZoom 15761
#define sipName_glPixelZoom &sipStrings_QtOpenGL[15761]
#define sipNameNr_glPointSize 15773
#define sipName_glPointSize &sipStrings_QtOpenGL[15773]
#define sipNameNr_glPopAttrib 15785
#define sipName_glPopAttrib &sipStrings_QtOpenGL[15785]
#define sipNameNr_glPopMatrix 15797
#define sipName_glPopMatrix &sipStrings_QtOpenGL[15797]
#define sipNameNr_glStencilOp 15809
#define sipName_glStencilOp &sipStrings_QtOpenGL[15809]
#define sipNameNr_glTexBuffer 15821
#define sipName_glTexBuffer &sipStrings_QtOpenGL[15821]
#define sipNameNr_glUniform1d 15833
#define sipName_glUniform1d &sipStrings_QtOpenGL[15833]
#define sipNameNr_glUniform1f 15845
#define sipName_glUniform1f &sipStrings_QtOpenGL[15845]
#define sipNameNr_glUniform1i 15857
#define sipName_glUniform1i &sipStrings_QtOpenGL[15857]
#define sipNameNr_glUniform2d 15869
#define sipName_glUniform2d &sipStrings_QtOpenGL[15869]
#define sipNameNr_glUniform2f 15881
#define sipName_glUniform2f &sipStrings_QtOpenGL[15881]
#define sipNameNr_glUniform2i 15893
#define sipName_glUniform2i &sipStrings_QtOpenGL[15893]
#define sipNameNr_glUniform3d 15905
#define sipName_glUniform3d &sipStrings_QtOpenGL[15905]
#define sipNameNr_glUniform3f 15917
#define sipName_glUniform3f &sipStrings_QtOpenGL[15917]
#define sipNameNr_glUniform3i 15929
#define sipName_glUniform3i &sipStrings_QtOpenGL[15929]
#define sipNameNr_glUniform4d 15941
#define sipName_glUniform4d &sipStrings_QtOpenGL[15941]
#define sipNameNr_glUniform4f 15953
#define sipName_glUniform4f &sipStrings_QtOpenGL[15953]
#define sipNameNr_glUniform4i 15965
#define sipName_glUniform4i &sipStrings_QtOpenGL[15965]
#define sipNameNr_glVertex2dv 15977
#define sipName_glVertex2dv &sipStrings_QtOpenGL[15977]
#define sipNameNr_glVertex2fv 15989
#define sipName_glVertex2fv &sipStrings_QtOpenGL[15989]
#define sipNameNr_glVertex2iv 16001
#define sipName_glVertex2iv &sipStrings_QtOpenGL[16001]
#define sipNameNr_glVertex2sv 16013
#define sipName_glVertex2sv &sipStrings_QtOpenGL[16013]
#define sipNameNr_glVertex3dv 16025
#define sipName_glVertex3dv &sipStrings_QtOpenGL[16025]
#define sipNameNr_glVertex3fv 16037
#define sipName_glVertex3fv &sipStrings_QtOpenGL[16037]
#define sipNameNr_glVertex3iv 16049
#define sipName_glVertex3iv &sipStrings_QtOpenGL[16049]
#define sipNameNr_glVertex3sv 16061
#define sipName_glVertex3sv &sipStrings_QtOpenGL[16061]
#define sipNameNr_glVertex4dv 16073
#define sipName_glVertex4dv &sipStrings_QtOpenGL[16073]
#define sipNameNr_glVertex4fv 16085
#define sipName_glVertex4fv &sipStrings_QtOpenGL[16085]
#define sipNameNr_glVertex4iv 16097
#define sipName_glVertex4iv &sipStrings_QtOpenGL[16097]
#define sipNameNr_glVertex4sv 16109
#define sipName_glVertex4sv &sipStrings_QtOpenGL[16109]
#define sipNameNr_hasProfiles 16121
#define sipName_hasProfiles &sipStrings_QtOpenGL[16121]
#define sipNameNr_imageHeight 16133
#define sipName_imageHeight &sipStrings_QtOpenGL[16133]
#define sipNameNr_loggingMode 16145
#define sipName_loggingMode &sipStrings_QtOpenGL[16145]
#define sipNameNr_makeCurrent 16157
#define sipName_makeCurrent &sipStrings_QtOpenGL[16157]
#define sipNameNr_mipMaxLevel 16169
#define sipName_mipMaxLevel &sipStrings_QtOpenGL[16169]
#define sipNameNr_nativeEvent 16181
#define sipName_nativeEvent &sipStrings_QtOpenGL[16181]
#define sipNameNr_paintEngine 16193
#define sipName_paintEngine &sipStrings_QtOpenGL[16193]
#define sipNameNr_paintOverGL 16205
#define sipName_paintOverGL &sipStrings_QtOpenGL[16205]
#define sipNameNr_resizeEvent 16217
#define sipName_resizeEvent &sipStrings_QtOpenGL[16217]
#define sipNameNr_sampleCount 16229
#define sipName_sampleCount &sipStrings_QtOpenGL[16229]
#define sipNameNr_setSkipRows 16241
#define sipName_setSkipRows &sipStrings_QtOpenGL[16241]
#define sipNameNr_setWrapMode 16253
#define sipName_setWrapMode &sipStrings_QtOpenGL[16253]
#define sipNameNr_stopLogging 16265
#define sipName_stopLogging &sipStrings_QtOpenGL[16265]
#define sipNameNr_surfaceType 16277
#define sipName_surfaceType &sipStrings_QtOpenGL[16277]
#define sipNameNr_swizzleMask 16289
#define sipName_swizzleMask &sipStrings_QtOpenGL[16289]
#define sipNameNr_tabletEvent 16301
#define sipName_tabletEvent &sipStrings_QtOpenGL[16301]
#define sipNameNr_takeTexture 16313
#define sipName_takeTexture &sipStrings_QtOpenGL[16313]
#define sipNameNr_AlphaValue 16325
#define sipName_AlphaValue &sipStrings_QtOpenGL[16325]
#define sipNameNr_Attachment 248
#define sipName_Attachment &sipStrings_QtOpenGL[248]
#define sipNameNr_DirectionR 16336
#define sipName_DirectionR &sipStrings_QtOpenGL[16336]
#define sipNameNr_DirectionS 16347
#define sipName_DirectionS &sipStrings_QtOpenGL[16347]
#define sipNameNr_DirectionT 16358
#define sipName_DirectionT &sipStrings_QtOpenGL[16358]
#define sipNameNr_Float16OES 16369
#define sipName_Float16OES &sipStrings_QtOpenGL[16369]
#define sipNameNr_GreenValue 16380
#define sipName_GreenValue &sipStrings_QtOpenGL[16380]
#define sipNameNr_MarkerType 16391
#define sipName_MarkerType &sipStrings_QtOpenGL[16391]
#define sipNameNr_RG16_SNorm 16402
#define sipName_RG16_SNorm &sipStrings_QtOpenGL[16402]
#define sipNameNr_RG16_UNorm 16413
#define sipName_RG16_UNorm &sipStrings_QtOpenGL[16413]
#define sipNameNr_RGB8_SNorm 16424
#define sipName_RGB8_SNorm &sipStrings_QtOpenGL[16424]
#define sipNameNr_RGB8_UNorm 16435
#define sipName_RGB8_UNorm &sipStrings_QtOpenGL[16435]
#define sipNameNr_RGBAFormat 16446
#define sipName_RGBAFormat &sipStrings_QtOpenGL[16446]
#define sipNameNr_RG_Integer 16457
#define sipName_RG_Integer &sipStrings_QtOpenGL[16457]
#define sipNameNr_RangeWrite 16468
#define sipName_RangeWrite &sipStrings_QtOpenGL[16468]
#define sipNameNr_SRGB8_ETC2 16479
#define sipName_SRGB8_ETC2 &sipStrings_QtOpenGL[16479]
#define sipNameNr_StaticCopy 16490
#define sipName_StaticCopy &sipStrings_QtOpenGL[16490]
#define sipNameNr_StaticDraw 16501
#define sipName_StaticDraw &sipStrings_QtOpenGL[16501]
#define sipNameNr_StaticRead 16512
#define sipName_StaticRead &sipStrings_QtOpenGL[16512]
#define sipNameNr_StreamCopy 16523
#define sipName_StreamCopy &sipStrings_QtOpenGL[16523]
#define sipNameNr_StreamDraw 16534
#define sipName_StreamDraw &sipStrings_QtOpenGL[16534]
#define sipNameNr_StreamRead 16545
#define sipName_StreamRead &sipStrings_QtOpenGL[16545]
#define sipNameNr_SwizzleRed 16556
#define sipName_SwizzleRed &sipStrings_QtOpenGL[16556]
#define sipNameNr_attachment 16567
#define sipName_attachment &sipStrings_QtOpenGL[16567]
#define sipNameNr_childEvent 16578
#define sipName_childEvent &sipStrings_QtOpenGL[16578]
#define sipNameNr_closeEvent 16589
#define sipName_closeEvent &sipStrings_QtOpenGL[16589]
#define sipNameNr_genMipMaps 16600
#define sipName_genMipMaps &sipStrings_QtOpenGL[16600]
#define sipNameNr_glCallList 16611
#define sipName_glCallList &sipStrings_QtOpenGL[16611]
#define sipNameNr_glColor3bv 16622
#define sipName_glColor3bv &sipStrings_QtOpenGL[16622]
#define sipNameNr_glColor3dv 16633
#define sipName_glColor3dv &sipStrings_QtOpenGL[16633]
#define sipNameNr_glColor3fv 16644
#define sipName_glColor3fv &sipStrings_QtOpenGL[16644]
#define sipNameNr_glColor3iv 16655
#define sipName_glColor3iv &sipStrings_QtOpenGL[16655]
#define sipNameNr_glColor3sv 16666
#define sipName_glColor3sv &sipStrings_QtOpenGL[16666]
#define sipNameNr_glColor3ub 16677
#define sipName_glColor3ub &sipStrings_QtOpenGL[16677]
#define sipNameNr_glColor3ui 16688
#define sipName_glColor3ui &sipStrings_QtOpenGL[16688]
#define sipNameNr_glColor3us 16699
#define sipName_glColor3us &sipStrings_QtOpenGL[16699]
#define sipNameNr_glColor4bv 16710
#define sipName_glColor4bv &sipStrings_QtOpenGL[16710]
#define sipNameNr_glColor4dv 16721
#define sipName_glColor4dv &sipStrings_QtOpenGL[16721]
#define sipNameNr_glColor4fv 16732
#define sipName_glColor4fv &sipStrings_QtOpenGL[16732]
#define sipNameNr_glColor4iv 16743
#define sipName_glColor4iv &sipStrings_QtOpenGL[16743]
#define sipNameNr_glColor4sv 16754
#define sipName_glColor4sv &sipStrings_QtOpenGL[16754]
#define sipNameNr_glColor4ub 16765
#define sipName_glColor4ub &sipStrings_QtOpenGL[16765]
#define sipNameNr_glColor4ui 16776
#define sipName_glColor4ui &sipStrings_QtOpenGL[16776]
#define sipNameNr_glColor4us 16787
#define sipName_glColor4us &sipStrings_QtOpenGL[16787]
#define sipNameNr_glCullFace 16798
#define sipName_glCullFace &sipStrings_QtOpenGL[16798]
#define sipNameNr_glDisablei 16809
#define sipName_glDisablei &sipStrings_QtOpenGL[16809]
#define sipNameNr_glEdgeFlag 16820
#define sipName_glEdgeFlag &sipStrings_QtOpenGL[16820]
#define sipNameNr_glEndQuery 16831
#define sipName_glEndQuery &sipStrings_QtOpenGL[16831]
#define sipNameNr_glGenLists 16842
#define sipName_glGenLists &sipStrings_QtOpenGL[16842]
#define sipNameNr_glGetError 16853
#define sipName_glGetError &sipStrings_QtOpenGL[16853]
#define sipNameNr_glIndexubv 16864
#define sipName_glIndexubv &sipStrings_QtOpenGL[16864]
#define sipNameNr_glIsBuffer 16875
#define sipName_glIsBuffer &sipStrings_QtOpenGL[16875]
#define sipNameNr_glIsShader 16886
#define sipName_glIsShader &sipStrings_QtOpenGL[16886]
#define sipNameNr_glListBase 16897
#define sipName_glListBase &sipStrings_QtOpenGL[16897]
#define sipNameNr_glLoadName 16908
#define sipName_glLoadName &sipStrings_QtOpenGL[16908]
#define sipNameNr_glNormal3b 16919
#define sipName_glNormal3b &sipStrings_QtOpenGL[16919]
#define sipNameNr_glNormal3d 16930
#define sipName_glNormal3d &sipStrings_QtOpenGL[16930]
#define sipNameNr_glNormal3f 16941
#define sipName_glNormal3f &sipStrings_QtOpenGL[16941]
#define sipNameNr_glNormal3i 16952
#define sipName_glNormal3i &sipStrings_QtOpenGL[16952]
#define sipNameNr_glNormal3s 16963
#define sipName_glNormal3s &sipStrings_QtOpenGL[16963]
#define sipNameNr_glPushName 16974
#define sipName_glPushName &sipStrings_QtOpenGL[16974]
#define sipNameNr_glTexEnvfv 16985
#define sipName_glTexEnvfv &sipStrings_QtOpenGL[16985]
#define sipNameNr_glTexEnviv 16996
#define sipName_glTexEnviv &sipStrings_QtOpenGL[16996]
#define sipNameNr_glTexGendv 17007
#define sipName_glTexGendv &sipStrings_QtOpenGL[17007]
#define sipNameNr_glTexGenfv 17018
#define sipName_glTexGenfv &sipStrings_QtOpenGL[17018]
#define sipNameNr_glTexGeniv 17029
#define sipName_glTexGeniv &sipStrings_QtOpenGL[17029]
#define sipNameNr_glVertex2d 17040
#define sipName_glVertex2d &sipStrings_QtOpenGL[17040]
#define sipNameNr_glVertex2f 17051
#define sipName_glVertex2f &sipStrings_QtOpenGL[17051]
#define sipNameNr_glVertex2i 17062
#define sipName_glVertex2i &sipStrings_QtOpenGL[17062]
#define sipNameNr_glVertex2s 17073
#define sipName_glVertex2s &sipStrings_QtOpenGL[17073]
#define sipNameNr_glVertex3d 17084
#define sipName_glVertex3d &sipStrings_QtOpenGL[17084]
#define sipNameNr_glVertex3f 17095
#define sipName_glVertex3f &sipStrings_QtOpenGL[17095]
#define sipNameNr_glVertex3i 17106
#define sipName_glVertex3i &sipStrings_QtOpenGL[17106]
#define sipNameNr_glVertex3s 17117
#define sipName_glVertex3s &sipStrings_QtOpenGL[17117]
#define sipNameNr_glVertex4d 17128
#define sipName_glVertex4d &sipStrings_QtOpenGL[17128]
#define sipNameNr_glVertex4f 17139
#define sipName_glVertex4f &sipStrings_QtOpenGL[17139]
#define sipNameNr_glVertex4i 17150
#define sipName_glVertex4i &sipStrings_QtOpenGL[17150]
#define sipNameNr_glVertex4s 17161
#define sipName_glVertex4s &sipStrings_QtOpenGL[17161]
#define sipNameNr_glViewport 17172
#define sipName_glViewport &sipStrings_QtOpenGL[17172]
#define sipNameNr_hasFeature 17183
#define sipName_hasFeature &sipStrings_QtOpenGL[17183]
#define sipNameNr_initialize 17194
#define sipName_initialize &sipStrings_QtOpenGL[17194]
#define sipNameNr_isCompiled 17205
#define sipName_isCompiled &sipStrings_QtOpenGL[17205]
#define sipNameNr_logMessage 17216
#define sipName_logMessage &sipStrings_QtOpenGL[17216]
#define sipNameNr_paintEvent 17227
#define sipName_paintEvent &sipStrings_QtOpenGL[17227]
#define sipNameNr_setOpacity 17238
#define sipName_setOpacity &sipStrings_QtOpenGL[17238]
#define sipNameNr_setProfile 17249
#define sipName_setProfile &sipStrings_QtOpenGL[17249]
#define sipNameNr_setSamples 17260
#define sipName_setSamples &sipStrings_QtOpenGL[17260]
#define sipNameNr_setVersion 17271
#define sipName_setVersion &sipStrings_QtOpenGL[17271]
#define sipNameNr_severities 17282
#define sipName_severities &sipStrings_QtOpenGL[17282]
#define sipNameNr_shaderType 17293
#define sipName_shaderType &sipStrings_QtOpenGL[17293]
#define sipNameNr_skipImages 17304
#define sipName_skipImages &sipStrings_QtOpenGL[17304]
#define sipNameNr_skipPixels 17315
#define sipName_skipPixels &sipStrings_QtOpenGL[17315]
#define sipNameNr_sourceCode 17326
#define sipName_sourceCode &sipStrings_QtOpenGL[17326]
#define sipNameNr_timerEvent 17337
#define sipName_timerEvent &sipStrings_QtOpenGL[17337]
#define sipNameNr_touchEvent 17348
#define sipName_touchEvent &sipStrings_QtOpenGL[17348]
#define sipNameNr_wheelEvent 17359
#define sipName_wheelEvent &sipStrings_QtOpenGL[17359]
#define sipNameNr_APISource 17370
#define sipName_APISource &sipStrings_QtOpenGL[17370]
#define sipNameNr_AnySource 17380
#define sipName_AnySource &sipStrings_QtOpenGL[17380]
#define sipNameNr_BlueValue 17390
#define sipName_BlueValue &sipStrings_QtOpenGL[17390]
#define sipNameNr_D32FS8X24 17400
#define sipName_D32FS8X24 &sipStrings_QtOpenGL[17400]
#define sipNameNr_DepthMode 17410
#define sipName_DepthMode &sipStrings_QtOpenGL[17410]
#define sipNameNr_ErrorType 17420
#define sipName_ErrorType &sipStrings_QtOpenGL[17420]
#define sipNameNr_Luminance 17430
#define sipName_Luminance &sipStrings_QtOpenGL[17430]
#define sipNameNr_OtherType 17440
#define sipName_OtherType &sipStrings_QtOpenGL[17440]
#define sipNameNr_PixelType 1999
#define sipName_PixelType &sipStrings_QtOpenGL[1999]
#define sipNameNr_R16_SNorm 17450
#define sipName_R16_SNorm &sipStrings_QtOpenGL[17450]
#define sipNameNr_R16_UNorm 17460
#define sipName_R16_UNorm &sipStrings_QtOpenGL[17460]
#define sipNameNr_RG8_SNorm 17470
#define sipName_RG8_SNorm &sipStrings_QtOpenGL[17470]
#define sipNameNr_RG8_UNorm 17480
#define sipName_RG8_UNorm &sipStrings_QtOpenGL[17480]
#define sipNameNr_RGB8_ETC1 17490
#define sipName_RGB8_ETC1 &sipStrings_QtOpenGL[17490]
#define sipNameNr_RGB8_ETC2 16480
#define sipName_RGB8_ETC2 &sipStrings_QtOpenGL[16480]
#define sipNameNr_RGBA_DXT1 17500
#define sipName_RGBA_DXT1 &sipStrings_QtOpenGL[17500]
#define sipNameNr_RGBA_DXT3 17510
#define sipName_RGBA_DXT3 &sipStrings_QtOpenGL[17510]
#define sipNameNr_RGBA_DXT5 17520
#define sipName_RGBA_DXT5 &sipStrings_QtOpenGL[17520]
#define sipNameNr_RGBFormat 17530
#define sipName_RGBFormat &sipStrings_QtOpenGL[17530]
#define sipNameNr_RangeRead 17540
#define sipName_RangeRead &sipStrings_QtOpenGL[17540]
#define sipNameNr_ReadWrite 17550
#define sipName_ReadWrite &sipStrings_QtOpenGL[17550]
#define sipNameNr_SRGB_DXT1 17560
#define sipName_SRGB_DXT1 &sipStrings_QtOpenGL[17560]
#define sipNameNr_Texture1D 3710
#define sipName_Texture1D &sipStrings_QtOpenGL[3710]
#define sipNameNr_Texture3D 3756
#define sipName_Texture3D &sipStrings_QtOpenGL[3756]
#define sipNameNr_WriteOnly 17570
#define sipName_WriteOnly &sipStrings_QtOpenGL[17570]
#define sipNameNr_ZeroValue 17580
#define sipName_ZeroValue &sipStrings_QtOpenGL[17580]
#define sipNameNr___enter__ 17590
#define sipName___enter__ &sipStrings_QtOpenGL[17590]
#define sipNameNr_addShader 17600
#define sipName_addShader &sipStrings_QtOpenGL[17600]
#define sipNameNr_alignment 17610
#define sipName_alignment &sipStrings_QtOpenGL[17610]
#define sipNameNr_glColor3b 17620
#define sipName_glColor3b &sipStrings_QtOpenGL[17620]
#define sipNameNr_glColor3d 17630
#define sipName_glColor3d &sipStrings_QtOpenGL[17630]
#define sipNameNr_glColor3f 17640
#define sipName_glColor3f &sipStrings_QtOpenGL[17640]
#define sipNameNr_glColor3i 17650
#define sipName_glColor3i &sipStrings_QtOpenGL[17650]
#define sipNameNr_glColor3s 17660
#define sipName_glColor3s &sipStrings_QtOpenGL[17660]
#define sipNameNr_glColor4b 17670
#define sipName_glColor4b &sipStrings_QtOpenGL[17670]
#define sipNameNr_glColor4d 17680
#define sipName_glColor4d &sipStrings_QtOpenGL[17680]
#define sipNameNr_glColor4f 17690
#define sipName_glColor4f &sipStrings_QtOpenGL[17690]
#define sipNameNr_glColor4i 17700
#define sipName_glColor4i &sipStrings_QtOpenGL[17700]
#define sipNameNr_glColor4s 17710
#define sipName_glColor4s &sipStrings_QtOpenGL[17710]
#define sipNameNr_glDisable 17720
#define sipName_glDisable &sipStrings_QtOpenGL[17720]
#define sipNameNr_glEnablei 17730
#define sipName_glEnablei &sipStrings_QtOpenGL[17730]
#define sipNameNr_glEndList 17740
#define sipName_glEndList &sipStrings_QtOpenGL[17740]
#define sipNameNr_glFrustum 17750
#define sipName_glFrustum &sipStrings_QtOpenGL[17750]
#define sipNameNr_glIndexdv 17760
#define sipName_glIndexdv &sipStrings_QtOpenGL[17760]
#define sipNameNr_glIndexfv 17770
#define sipName_glIndexfv &sipStrings_QtOpenGL[17770]
#define sipNameNr_glIndexiv 17780
#define sipName_glIndexiv &sipStrings_QtOpenGL[17780]
#define sipNameNr_glIndexsv 17790
#define sipName_glIndexsv &sipStrings_QtOpenGL[17790]
#define sipNameNr_glIndexub 17800
#define sipName_glIndexub &sipStrings_QtOpenGL[17800]
#define sipNameNr_glIsQuery 17810
#define sipName_glIsQuery &sipStrings_QtOpenGL[17810]
#define sipNameNr_glLightfv 17820
#define sipName_glLightfv &sipStrings_QtOpenGL[17820]
#define sipNameNr_glLightiv 17830
#define sipName_glLightiv &sipStrings_QtOpenGL[17830]
#define sipNameNr_glLogicOp 17840
#define sipName_glLogicOp &sipStrings_QtOpenGL[17840]
#define sipNameNr_glNewList 17850
#define sipName_glNewList &sipStrings_QtOpenGL[17850]
#define sipNameNr_glPopName 17860
#define sipName_glPopName &sipStrings_QtOpenGL[17860]
#define sipNameNr_glRotated 17870
#define sipName_glRotated &sipStrings_QtOpenGL[17870]
#define sipNameNr_glRotatef 17880
#define sipName_glRotatef &sipStrings_QtOpenGL[17880]
#define sipNameNr_glScissor 17890
#define sipName_glScissor &sipStrings_QtOpenGL[17890]
#define sipNameNr_glTexEnvf 17900
#define sipName_glTexEnvf &sipStrings_QtOpenGL[17900]
#define sipNameNr_glTexEnvi 17910
#define sipName_glTexEnvi &sipStrings_QtOpenGL[17910]
#define sipNameNr_glTexGend 17920
#define sipName_glTexGend &sipStrings_QtOpenGL[17920]
#define sipNameNr_glTexGenf 17930
#define sipName_glTexGenf &sipStrings_QtOpenGL[17930]
#define sipNameNr_glTexGeni 17940
#define sipName_glTexGeni &sipStrings_QtOpenGL[17940]
#define sipNameNr_hideEvent 17950
#define sipName_hideEvent &sipStrings_QtOpenGL[17950]
#define sipNameNr_isCreated 17960
#define sipName_isCreated &sipStrings_QtOpenGL[17960]
#define sipNameNr_isLogging 17970
#define sipName_isLogging &sipStrings_QtOpenGL[17970]
#define sipNameNr_mipLevels 17980
#define sipName_mipLevels &sipStrings_QtOpenGL[17980]
#define sipNameNr_moveEvent 17990
#define sipName_moveEvent &sipStrings_QtOpenGL[17990]
#define sipNameNr_objectIds 18000
#define sipName_objectIds &sipStrings_QtOpenGL[18000]
#define sipNameNr_programId 18010
#define sipName_programId &sipStrings_QtOpenGL[18010]
#define sipNameNr_pushGroup 18020
#define sipName_pushGroup &sipStrings_QtOpenGL[18020]
#define sipNameNr_rowLength 18030
#define sipName_rowLength &sipStrings_QtOpenGL[18030]
#define sipNameNr_setFormat 18040
#define sipName_setFormat &sipStrings_QtOpenGL[18040]
#define sipNameNr_setLayers 18050
#define sipName_setLayers &sipStrings_QtOpenGL[18050]
#define sipNameNr_setMipmap 18060
#define sipName_setMipmap &sipStrings_QtOpenGL[18060]
#define sipNameNr_showEvent 18070
#define sipName_showEvent &sipStrings_QtOpenGL[18070]
#define sipNameNr_textureId 18080
#define sipName_textureId &sipStrings_QtOpenGL[18080]
#define sipNameNr_Fragment 18090
#define sipName_Fragment &sipStrings_QtOpenGL[18090]
#define sipNameNr_Geometry 18099
#define sipName_Geometry &sipStrings_QtOpenGL[18099]
#define sipNameNr_NoFormat 18108
#define sipName_NoFormat &sipStrings_QtOpenGL[18108]
#define sipNameNr_OneValue 18117
#define sipName_OneValue &sipStrings_QtOpenGL[18117]
#define sipNameNr_R8_SNorm 18126
#define sipName_R8_SNorm &sipStrings_QtOpenGL[18126]
#define sipNameNr_R8_UNorm 18135
#define sipName_R8_UNorm &sipStrings_QtOpenGL[18135]
#define sipNameNr_RG11B10F 10323
#define sipName_RG11B10F &sipStrings_QtOpenGL[10323]
#define sipNameNr_RGB_DXT1 17561
#define sipName_RGB_DXT1 &sipStrings_QtOpenGL[17561]
#define sipNameNr_ReadOnly 18144
#define sipName_ReadOnly &sipStrings_QtOpenGL[18144]
#define sipNameNr_RedValue 18153
#define sipName_RedValue &sipStrings_QtOpenGL[18153]
#define sipNameNr_Severity 1162
#define sipName_Severity &sipStrings_QtOpenGL[1162]
#define sipNameNr_Target1D 10035
#define sipName_Target1D &sipStrings_QtOpenGL[10035]
#define sipNameNr_Target2D 10051
#define sipName_Target2D &sipStrings_QtOpenGL[10051]
#define sipNameNr_Target3D 10067
#define sipName_Target3D &sipStrings_QtOpenGL[10067]
#define sipNameNr_WrapMode 2439
#define sipName_WrapMode &sipStrings_QtOpenGL[2439]
#define sipNameNr___exit__ 18162
#define sipName___exit__ &sipStrings_QtOpenGL[18162]
#define sipNameNr___hash__ 18171
#define sipName___hash__ &sipStrings_QtOpenGL[18171]
#define sipNameNr_allocate 18180
#define sipName_allocate &sipStrings_QtOpenGL[18180]
#define sipNameNr_bufferId 18189
#define sipName_bufferId &sipStrings_QtOpenGL[18189]
#define sipNameNr_glBitmap 18198
#define sipName_glBitmap &sipStrings_QtOpenGL[18198]
#define sipNameNr_glEnable 18207
#define sipName_glEnable &sipStrings_QtOpenGL[18207]
#define sipNameNr_glFinish 18216
#define sipName_glFinish &sipStrings_QtOpenGL[18216]
#define sipNameNr_glIndexd 18225
#define sipName_glIndexd &sipStrings_QtOpenGL[18225]
#define sipNameNr_glIndexf 18234
#define sipName_glIndexf &sipStrings_QtOpenGL[18234]
#define sipNameNr_glIndexi 18243
#define sipName_glIndexi &sipStrings_QtOpenGL[18243]
#define sipNameNr_glIndexs 18252
#define sipName_glIndexs &sipStrings_QtOpenGL[18252]
#define sipNameNr_glIsList 18261
#define sipName_glIsList &sipStrings_QtOpenGL[18261]
#define sipNameNr_glLightf 18270
#define sipName_glLightf &sipStrings_QtOpenGL[18270]
#define sipNameNr_glLighti 18279
#define sipName_glLighti &sipStrings_QtOpenGL[18279]
#define sipNameNr_glMinmax 18288
#define sipName_glMinmax &sipStrings_QtOpenGL[18288]
#define sipNameNr_glScaled 18297
#define sipName_glScaled &sipStrings_QtOpenGL[18297]
#define sipNameNr_glScalef 18306
#define sipName_glScalef &sipStrings_QtOpenGL[18306]
#define sipNameNr_isLinked 18315
#define sipName_isLinked &sipStrings_QtOpenGL[18315]
#define sipNameNr_mapRange 18324
#define sipName_mapRange &sipStrings_QtOpenGL[18324]
#define sipNameNr_objectId 18333
#define sipName_objectId &sipStrings_QtOpenGL[18333]
#define sipNameNr_popGroup 18342
#define sipName_popGroup &sipStrings_QtOpenGL[18342]
#define sipNameNr_resizeGL 18351
#define sipName_resizeGL &sipStrings_QtOpenGL[18351]
#define sipNameNr_severity 18360
#define sipName_severity &sipStrings_QtOpenGL[18360]
#define sipNameNr_shaderId 18369
#define sipName_shaderId &sipStrings_QtOpenGL[18369]
#define sipNameNr_skipRows 18378
#define sipName_skipRows &sipStrings_QtOpenGL[18378]
#define sipNameNr_textures 18387
#define sipName_textures &sipStrings_QtOpenGL[18387]
#define sipNameNr_wrapMode 18396
#define sipName_wrapMode &sipStrings_QtOpenGL[18396]
#define sipNameNr_AnyType 18405
#define sipName_AnyType &sipStrings_QtOpenGL[18405]
#define sipNameNr_Compute 18413
#define sipName_Compute &sipStrings_QtOpenGL[18413]
#define sipNameNr_Feature 2838
#define sipName_Feature &sipStrings_QtOpenGL[2838]
#define sipNameNr_Float16 18421
#define sipName_Float16 &sipStrings_QtOpenGL[18421]
#define sipNameNr_Float32 18429
#define sipName_Float32 &sipStrings_QtOpenGL[18429]
#define sipNameNr_Nearest 4879
#define sipName_Nearest &sipStrings_QtOpenGL[4879]
#define sipNameNr_RGB10A2 11220
#define sipName_RGB10A2 &sipStrings_QtOpenGL[11220]
#define sipNameNr_RGBA16F 18437
#define sipName_RGBA16F &sipStrings_QtOpenGL[18437]
#define sipNameNr_RGBA16I 18445
#define sipName_RGBA16I &sipStrings_QtOpenGL[18445]
#define sipNameNr_RGBA16U 18453
#define sipName_RGBA16U &sipStrings_QtOpenGL[18453]
#define sipNameNr_RGBA32F 18461
#define sipName_RGBA32F &sipStrings_QtOpenGL[18461]
#define sipNameNr_RGBA32I 18469
#define sipName_RGBA32I &sipStrings_QtOpenGL[18469]
#define sipNameNr_RGBA32U 18477
#define sipName_RGBA32U &sipStrings_QtOpenGL[18477]
#define sipNameNr_Stencil 4816
#define sipName_Stencil &sipStrings_QtOpenGL[4816]
#define sipNameNr_Swizzle 9068
#define sipName_Swizzle &sipStrings_QtOpenGL[9068]
#define sipNameNr___len__ 18485
#define sipName___len__ &sipStrings_QtOpenGL[18485]
#define sipNameNr_buffers 18493
#define sipName_buffers &sipStrings_QtOpenGL[18493]
#define sipNameNr_context 18501
#define sipName_context &sipStrings_QtOpenGL[18501]
#define sipNameNr_destroy 18509
#define sipName_destroy &sipStrings_QtOpenGL[18509]
#define sipNameNr_flipped 18517
#define sipName_flipped &sipStrings_QtOpenGL[18517]
#define sipNameNr_glAccum 18525
#define sipName_glAccum &sipStrings_QtOpenGL[18525]
#define sipNameNr_glBegin 18533
#define sipName_glBegin &sipStrings_QtOpenGL[18533]
#define sipNameNr_glClear 18541
#define sipName_glClear &sipStrings_QtOpenGL[18541]
#define sipNameNr_glFlush 18549
#define sipName_glFlush &sipStrings_QtOpenGL[18549]
#define sipNameNr_glFogfv 18557
#define sipName_glFogfv &sipStrings_QtOpenGL[18557]
#define sipNameNr_glFogiv 18565
#define sipName_glFogiv &sipStrings_QtOpenGL[18565]
#define sipNameNr_glMap1d 18573
#define sipName_glMap1d &sipStrings_QtOpenGL[18573]
#define sipNameNr_glMap1f 18581
#define sipName_glMap1f &sipStrings_QtOpenGL[18581]
#define sipNameNr_glMap2d 18589
#define sipName_glMap2d &sipStrings_QtOpenGL[18589]
#define sipNameNr_glMap2f 18597
#define sipName_glMap2f &sipStrings_QtOpenGL[18597]
#define sipNameNr_glOrtho 18605
#define sipName_glOrtho &sipStrings_QtOpenGL[18605]
#define sipNameNr_glRectd 18613
#define sipName_glRectd &sipStrings_QtOpenGL[18613]
#define sipNameNr_glRectf 18621
#define sipName_glRectf &sipStrings_QtOpenGL[18621]
#define sipNameNr_glRecti 18629
#define sipName_glRecti &sipStrings_QtOpenGL[18629]
#define sipNameNr_glRects 18637
#define sipName_glRects &sipStrings_QtOpenGL[18637]
#define sipNameNr_isBound 18645
#define sipName_isBound &sipStrings_QtOpenGL[18645]
#define sipNameNr_isValid 18653
#define sipName_isValid &sipStrings_QtOpenGL[18653]
#define sipNameNr_message 18661
#define sipName_message &sipStrings_QtOpenGL[18661]
#define sipNameNr_options 18669
#define sipName_options &sipStrings_QtOpenGL[18669]
#define sipNameNr_paintGL 18677
#define sipName_paintGL &sipStrings_QtOpenGL[18677]
#define sipNameNr_profile 18685
#define sipName_profile &sipStrings_QtOpenGL[18685]
#define sipNameNr_release 18693
#define sipName_release &sipStrings_QtOpenGL[18693]
#define sipNameNr_samples 18701
#define sipName_samples &sipStrings_QtOpenGL[18701]
#define sipNameNr_setData 18709
#define sipName_setData &sipStrings_QtOpenGL[18709]
#define sipNameNr_setSize 18717
#define sipName_setSize &sipStrings_QtOpenGL[18717]
#define sipNameNr_shaders 18725
#define sipName_shaders &sipStrings_QtOpenGL[18725]
#define sipNameNr_sources 18733
#define sipName_sources &sipStrings_QtOpenGL[18733]
#define sipNameNr_texture 18741
#define sipName_texture &sipStrings_QtOpenGL[18741]
#define sipNameNr_toImage 18749
#define sipName_toImage &sipStrings_QtOpenGL[18749]
#define sipNameNr_version 18757
#define sipName_version &sipStrings_QtOpenGL[18757]
#define sipNameNr_Access 3964
#define sipName_Access &sipStrings_QtOpenGL[3964]
#define sipNameNr_Binder 661
#define sipName_Binder &sipStrings_QtOpenGL[661]
#define sipNameNr_Filter 3460
#define sipName_Filter &sipStrings_QtOpenGL[3460]
#define sipNameNr_Linear 5482
#define sipName_Linear &sipStrings_QtOpenGL[5482]
#define sipNameNr_Origin 1254
#define sipName_Origin &sipStrings_QtOpenGL[1254]
#define sipNameNr_R5G6B5 12367
#define sipName_R5G6B5 &sipStrings_QtOpenGL[12367]
#define sipNameNr_RGB16F 18765
#define sipName_RGB16F &sipStrings_QtOpenGL[18765]
#define sipNameNr_RGB16I 18772
#define sipName_RGB16I &sipStrings_QtOpenGL[18772]
#define sipNameNr_RGB16U 18779
#define sipName_RGB16U &sipStrings_QtOpenGL[18779]
#define sipNameNr_RGB32F 18786
#define sipName_RGB32F &sipStrings_QtOpenGL[18786]
#define sipNameNr_RGB32I 18793
#define sipName_RGB32I &sipStrings_QtOpenGL[18793]
#define sipNameNr_RGB32U 18800
#define sipName_RGB32U &sipStrings_QtOpenGL[18800]
#define sipNameNr_RGB5A1 12381
#define sipName_RGB5A1 &sipStrings_QtOpenGL[12381]
#define sipNameNr_RGB9E5 18807
#define sipName_RGB9E5 &sipStrings_QtOpenGL[18807]
#define sipNameNr_RGBA8I 18814
#define sipName_RGBA8I &sipStrings_QtOpenGL[18814]
#define sipNameNr_RGBA8U 18821
#define sipName_RGBA8U &sipStrings_QtOpenGL[18821]
#define sipNameNr_Repeat 7863
#define sipName_Repeat &sipStrings_QtOpenGL[7863]
#define sipNameNr_Source 1515
#define sipName_Source &sipStrings_QtOpenGL[1515]
#define sipNameNr_Target 1194
#define sipName_Target &sipStrings_QtOpenGL[1194]
#define sipNameNr_UInt16 18828
#define sipName_UInt16 &sipStrings_QtOpenGL[18828]
#define sipNameNr_UInt32 18835
#define sipName_UInt32 &sipStrings_QtOpenGL[18835]
#define sipNameNr_Vertex 8547
#define sipName_Vertex &sipStrings_QtOpenGL[8547]
#define sipNameNr___eq__ 18842
#define sipName___eq__ &sipStrings_QtOpenGL[18842]
#define sipNameNr___ne__ 18849
#define sipName___ne__ &sipStrings_QtOpenGL[18849]
#define sipNameNr_create 18856
#define sipName_create &sipStrings_QtOpenGL[18856]
#define sipNameNr_filter 18863
#define sipName_filter &sipStrings_QtOpenGL[18863]
#define sipNameNr_format 10805
#define sipName_format &sipStrings_QtOpenGL[10805]
#define sipNameNr_glFogf 18870
#define sipName_glFogf &sipStrings_QtOpenGL[18870]
#define sipNameNr_glFogi 18877
#define sipName_glFogi &sipStrings_QtOpenGL[18877]
#define sipNameNr_glHint 18884
#define sipName_glHint &sipStrings_QtOpenGL[18884]
#define sipNameNr_handle 18891
#define sipName_handle &sipStrings_QtOpenGL[18891]
#define sipNameNr_height 18898
#define sipName_height &sipStrings_QtOpenGL[18898]
#define sipNameNr_layers 18905
#define sipName_layers &sipStrings_QtOpenGL[18905]
#define sipNameNr_metric 18912
#define sipName_metric &sipStrings_QtOpenGL[18912]
#define sipNameNr_mipmap 18919
#define sipName_mipmap &sipStrings_QtOpenGL[18919]
#define sipNameNr_parent 18926
#define sipName_parent &sipStrings_QtOpenGL[18926]
#define sipNameNr_rebind 18933
#define sipName_rebind &sipStrings_QtOpenGL[18933]
#define sipNameNr_source 18940
#define sipName_source &sipStrings_QtOpenGL[18940]
#define sipNameNr_stride 18947
#define sipName_stride &sipStrings_QtOpenGL[18947]
#define sipNameNr_target 18954
#define sipName_target &sipStrings_QtOpenGL[18954]
#define sipNameNr_Alpha 11012
#define sipName_Alpha &sipStrings_QtOpenGL[11012]
#define sipNameNr_D24S8 13795
#define sipName_D24S8 &sipStrings_QtOpenGL[13795]
#define sipNameNr_Depth 13964
#define sipName_Depth &sipStrings_QtOpenGL[13964]
#define sipNameNr_Int16 18829
#define sipName_Int16 &sipStrings_QtOpenGL[18829]
#define sipNameNr_Int32 18836
#define sipName_Int32 &sipStrings_QtOpenGL[18836]
#define sipNameNr_RG16F 18961
#define sipName_RG16F &sipStrings_QtOpenGL[18961]
#define sipNameNr_RG16I 18967
#define sipName_RG16I &sipStrings_QtOpenGL[18967]
#define sipNameNr_RG16U 18973
#define sipName_RG16U &sipStrings_QtOpenGL[18973]
#define sipNameNr_RG32F 18979
#define sipName_RG32F &sipStrings_QtOpenGL[18979]
#define sipNameNr_RG32I 18985
#define sipName_RG32I &sipStrings_QtOpenGL[18985]
#define sipNameNr_RG32U 18991
#define sipName_RG32U &sipStrings_QtOpenGL[18991]
#define sipNameNr_RG3B2 15203
#define sipName_RG3B2 &sipStrings_QtOpenGL[15203]
#define sipNameNr_RGB8I 18997
#define sipName_RGB8I &sipStrings_QtOpenGL[18997]
#define sipNameNr_RGB8U 19003
#define sipName_RGB8U &sipStrings_QtOpenGL[19003]
#define sipNameNr_RGBA4 13782
#define sipName_RGBA4 &sipStrings_QtOpenGL[13782]
#define sipNameNr_SRGB8 19009
#define sipName_SRGB8 &sipStrings_QtOpenGL[19009]
#define sipNameNr_UInt8 19015
#define sipName_UInt8 &sipStrings_QtOpenGL[19015]
#define sipNameNr_begin 19021
#define sipName_begin &sipStrings_QtOpenGL[19021]
#define sipNameNr_depth 19027
#define sipName_depth &sipStrings_QtOpenGL[19027]
#define sipNameNr_event 19033
#define sipName_event &sipStrings_QtOpenGL[19033]
#define sipNameNr_faces 19039
#define sipName_faces &sipStrings_QtOpenGL[19039]
#define sipNameNr_glEnd 19045
#define sipName_glEnd &sipStrings_QtOpenGL[19045]
#define sipNameNr_reset 19051
#define sipName_reset &sipStrings_QtOpenGL[19051]
#define sipNameNr_sizes 19057
#define sipName_sizes &sipStrings_QtOpenGL[19057]
#define sipNameNr_types 19063
#define sipName_types &sipStrings_QtOpenGL[19063]
#define sipNameNr_unmap 19069
#define sipName_unmap &sipStrings_QtOpenGL[19069]
#define sipNameNr_width 19075
#define sipName_width &sipStrings_QtOpenGL[19075]
#define sipNameNr_write 19081
#define sipName_write &sipStrings_QtOpenGL[19081]
#define sipNameNr_BGRA 19087
#define sipName_BGRA &sipStrings_QtOpenGL[19087]
#define sipNameNr_D32F 19092
#define sipName_D32F &sipStrings_QtOpenGL[19092]
#define sipNameNr_Int8 19016
#define sipName_Int8 &sipStrings_QtOpenGL[19016]
#define sipNameNr_R16F 19097
#define sipName_R16F &sipStrings_QtOpenGL[19097]
#define sipNameNr_R16I 19102
#define sipName_R16I &sipStrings_QtOpenGL[19102]
#define sipNameNr_R16U 19107
#define sipName_R16U &sipStrings_QtOpenGL[19107]
#define sipNameNr_R32F 19112
#define sipName_R32F &sipStrings_QtOpenGL[19112]
#define sipNameNr_R32I 19117
#define sipName_R32I &sipStrings_QtOpenGL[19117]
#define sipNameNr_R32U 19122
#define sipName_R32U &sipStrings_QtOpenGL[19122]
#define sipNameNr_RG8I 19127
#define sipName_RG8I &sipStrings_QtOpenGL[19127]
#define sipNameNr_RG8U 19132
#define sipName_RG8U &sipStrings_QtOpenGL[19132]
#define sipNameNr_RGBA 19137
#define sipName_RGBA &sipStrings_QtOpenGL[19137]
#define sipNameNr_Type 1952
#define sipName_Type &sipStrings_QtOpenGL[1952]
#define sipNameNr_bind 18935
#define sipName_bind &sipStrings_QtOpenGL[18935]
#define sipNameNr_blit 19142
#define sipName_blit &sipStrings_QtOpenGL[19142]
#define sipNameNr_link 19147
#define sipName_link &sipStrings_QtOpenGL[19147]
#define sipNameNr_read 19152
#define sipName_read &sipStrings_QtOpenGL[19152]
#define sipNameNr_size 19157
#define sipName_size &sipStrings_QtOpenGL[19157]
#define sipNameNr_swap 19162
#define sipName_swap &sipStrings_QtOpenGL[19162]
#define sipNameNr_type 19167
#define sipName_type &sipStrings_QtOpenGL[19167]
#define sipNameNr_BGR 19172
#define sipName_BGR &sipStrings_QtOpenGL[19172]
#define sipNameNr_D16 19176
#define sipName_D16 &sipStrings_QtOpenGL[19176]
#define sipNameNr_D24 19180
#define sipName_D24 &sipStrings_QtOpenGL[19180]
#define sipNameNr_D32 19184
#define sipName_D32 &sipStrings_QtOpenGL[19184]
#define sipNameNr_R8I 19188
#define sipName_R8I &sipStrings_QtOpenGL[19188]
#define sipNameNr_R8U 19192
#define sipName_R8U &sipStrings_QtOpenGL[19192]
#define sipNameNr_RGB 19196
#define sipName_RGB &sipStrings_QtOpenGL[19196]
#define sipNameNr_Red 16563
#define sipName_Red &sipStrings_QtOpenGL[16563]
#define sipNameNr_end 6443
#define sipName_end &sipStrings_QtOpenGL[6443]
#define sipNameNr_get 1197
#define sipName_get &sipStrings_QtOpenGL[1197]
#define sipNameNr_log 19200
#define sipName_log &sipStrings_QtOpenGL[19200]
#define sipNameNr_map 9480
#define sipName_map &sipStrings_QtOpenGL[9480]
#define sipNameNr_RG 19204
#define sipName_RG &sipStrings_QtOpenGL[19204]
#define sipNameNr_S8 13798
#define sipName_S8 &sipStrings_QtOpenGL[13798]
#define sipNameNr_id 18658
#define sipName_id &sipStrings_QtOpenGL[18658]

#define sipMalloc                   sipAPI_QtOpenGL->api_malloc
#define sipFree                     sipAPI_QtOpenGL->api_free
#define sipBuildResult              sipAPI_QtOpenGL->api_build_result
#define sipCallMethod               sipAPI_QtOpenGL->api_call_method
#define sipCallProcedureMethod      sipAPI_QtOpenGL->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtOpenGL->api_call_error_handler
#define sipParseResultEx            sipAPI_QtOpenGL->api_parse_result_ex
#define sipParseResult              sipAPI_QtOpenGL->api_parse_result
#define sipParseArgs                sipAPI_QtOpenGL->api_parse_args
#define sipParseKwdArgs             sipAPI_QtOpenGL->api_parse_kwd_args
#define sipParsePair                sipAPI_QtOpenGL->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtOpenGL->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtOpenGL->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtOpenGL->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtOpenGL->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtOpenGL->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtOpenGL->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtOpenGL->api_add_exception
#define sipNoFunction               sipAPI_QtOpenGL->api_no_function
#define sipNoMethod                 sipAPI_QtOpenGL->api_no_method
#define sipAbstractMethod           sipAPI_QtOpenGL->api_abstract_method
#define sipBadClass                 sipAPI_QtOpenGL->api_bad_class
#define sipBadCatcherResult         sipAPI_QtOpenGL->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtOpenGL->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtOpenGL->api_bad_operator_arg
#define sipTrace                    sipAPI_QtOpenGL->api_trace
#define sipTransferBack             sipAPI_QtOpenGL->api_transfer_back
#define sipTransferTo               sipAPI_QtOpenGL->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtOpenGL->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtOpenGL->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtOpenGL->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtOpenGL->api_voidptr_type
#define sipGetPyObject              sipAPI_QtOpenGL->api_get_pyobject
#define sipGetAddress               sipAPI_QtOpenGL->api_get_address
#define sipGetMixinAddress          sipAPI_QtOpenGL->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtOpenGL->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtOpenGL->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtOpenGL->api_call_hook
#define sipEndThread                sipAPI_QtOpenGL->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtOpenGL->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtOpenGL->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtOpenGL->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtOpenGL->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtOpenGL->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtOpenGL->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtOpenGL->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtOpenGL->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtOpenGL->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtOpenGL->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtOpenGL->api_convert_to_bool
#define sipReleaseType              sipAPI_QtOpenGL->api_release_type
#define sipConvertFromType          sipAPI_QtOpenGL->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtOpenGL->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtOpenGL->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtOpenGL->api_convert_from_enum
#define sipGetState                 sipAPI_QtOpenGL->api_get_state
#define sipExportSymbol             sipAPI_QtOpenGL->api_export_symbol
#define sipImportSymbol             sipAPI_QtOpenGL->api_import_symbol
#define sipFindType                 sipAPI_QtOpenGL->api_find_type
#define sipBytes_AsChar             sipAPI_QtOpenGL->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtOpenGL->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtOpenGL->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtOpenGL->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtOpenGL->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtOpenGL->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtOpenGL->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtOpenGL->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtOpenGL->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtOpenGL->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtOpenGL->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtOpenGL->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtOpenGL->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtOpenGL->api_get_reference
#define sipKeepReference            sipAPI_QtOpenGL->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtOpenGL->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtOpenGL->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtOpenGL->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtOpenGL->api_type_scope
#define sipResolveTypedef           sipAPI_QtOpenGL->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtOpenGL->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtOpenGL->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtOpenGL->api_init_mixin
#define sipExportModule             sipAPI_QtOpenGL->api_export_module
#define sipInitModule               sipAPI_QtOpenGL->api_init_module
#define sipGetInterpreter           sipAPI_QtOpenGL->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtOpenGL->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtOpenGL->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtOpenGL->api_py_type_dict
#define sipPyTypeName               sipAPI_QtOpenGL->api_py_type_name
#define sipGetCFunction             sipAPI_QtOpenGL->api_get_c_function
#define sipGetMethod                sipAPI_QtOpenGL->api_get_method
#define sipFromMethod               sipAPI_QtOpenGL->api_from_method
#define sipGetDate                  sipAPI_QtOpenGL->api_get_date
#define sipFromDate                 sipAPI_QtOpenGL->api_from_date
#define sipGetDateTime              sipAPI_QtOpenGL->api_get_datetime
#define sipFromDateTime             sipAPI_QtOpenGL->api_from_datetime
#define sipGetTime                  sipAPI_QtOpenGL->api_get_time
#define sipFromTime                 sipAPI_QtOpenGL->api_from_time
#define sipIsUserType               sipAPI_QtOpenGL->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtOpenGL->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtOpenGL->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtOpenGL->api_unicode_write
#define sipUnicodeData              sipAPI_QtOpenGL->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtOpenGL->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtOpenGL->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtOpenGL->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtOpenGL->api_is_derived_class
#define sipGetUserObject            sipAPI_QtOpenGL->api_get_user_object
#define sipSetUserObject            sipAPI_QtOpenGL->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtOpenGL->api_register_event_handler
#define sipConvertToArray           sipAPI_QtOpenGL->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtOpenGL->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtOpenGL->api_enable_gc
#define sipPrintObject              sipAPI_QtOpenGL->api_print_object
#define sipLong_AsChar              sipAPI_QtOpenGL->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtOpenGL->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtOpenGL->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtOpenGL->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtOpenGL->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtOpenGL->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtOpenGL->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtOpenGL->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtOpenGL->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtOpenGL->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtOpenGL->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtOpenGL->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtOpenGL->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtOpenGL->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtOpenGL->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtOpenGL->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtOpenGL->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtOpenGL->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtOpenGL->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtOpenGL->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtOpenGL->api_release_type_us
#define sipIsPyMethod               sipAPI_QtOpenGL->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtOpenGL[];

#define sipType_QOpenGLBuffer sipExportedTypes_QtOpenGL[10]

#define sipType_QOpenGLBuffer_RangeAccessFlag sipExportedTypes_QtOpenGL[12]

#define sipType_QOpenGLBuffer_Access sipExportedTypes_QtOpenGL[11]

#define sipType_QOpenGLBuffer_UsagePattern sipExportedTypes_QtOpenGL[14]

#define sipType_QOpenGLBuffer_Type sipExportedTypes_QtOpenGL[13]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLBuffer;

#define sipType_QOpenGLDebugMessage sipExportedTypes_QtOpenGL[17]

#define sipType_QOpenGLDebugMessage_Severity sipExportedTypes_QtOpenGL[18]

#define sipType_QOpenGLDebugMessage_Type sipExportedTypes_QtOpenGL[20]

#define sipType_QOpenGLDebugMessage_Source sipExportedTypes_QtOpenGL[19]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLDebugMessage;

#define sipType_QOpenGLDebugLogger sipExportedTypes_QtOpenGL[15]

#define sipType_QOpenGLDebugLogger_LoggingMode sipExportedTypes_QtOpenGL[16]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLDebugLogger;

#define sipType_QOpenGLFramebufferObject sipExportedTypes_QtOpenGL[21]

#define sipType_QOpenGLFramebufferObject_FramebufferRestorePolicy sipExportedTypes_QtOpenGL[23]

#define sipType_QOpenGLFramebufferObject_Attachment sipExportedTypes_QtOpenGL[22]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLFramebufferObject;

#define sipType_QOpenGLFramebufferObjectFormat sipExportedTypes_QtOpenGL[24]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLFramebufferObjectFormat;

#define sipType_QOpenGLPaintDevice sipExportedTypes_QtOpenGL[28]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLPaintDevice;

#define sipType_QOpenGLPixelTransferOptions sipExportedTypes_QtOpenGL[29]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLPixelTransferOptions;

#define sipType_QOpenGLShader sipExportedTypes_QtOpenGL[30]

#define sipType_QOpenGLShader_ShaderTypeBit sipExportedTypes_QtOpenGL[31]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLShader;

#define sipType_QOpenGLShaderProgram sipExportedTypes_QtOpenGL[32]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLShaderProgram;

#define sipType_QOpenGLTexture sipExportedTypes_QtOpenGL[33]

#define sipType_QOpenGLTexture_ComparisonMode sipExportedTypes_QtOpenGL[36]

#define sipType_QOpenGLTexture_ComparisonFunction sipExportedTypes_QtOpenGL[35]

#define sipType_QOpenGLTexture_CoordinateDirection sipExportedTypes_QtOpenGL[37]

#define sipType_QOpenGLTexture_WrapMode sipExportedTypes_QtOpenGL[50]

#define sipType_QOpenGLTexture_Filter sipExportedTypes_QtOpenGL[41]

#define sipType_QOpenGLTexture_DepthStencilMode sipExportedTypes_QtOpenGL[39]

#define sipType_QOpenGLTexture_SwizzleValue sipExportedTypes_QtOpenGL[46]

#define sipType_QOpenGLTexture_SwizzleComponent sipExportedTypes_QtOpenGL[45]

#define sipType_QOpenGLTexture_Feature sipExportedTypes_QtOpenGL[40]

#define sipType_QOpenGLTexture_PixelType sipExportedTypes_QtOpenGL[44]

#define sipType_QOpenGLTexture_PixelFormat sipExportedTypes_QtOpenGL[43]

#define sipType_QOpenGLTexture_CubeMapFace sipExportedTypes_QtOpenGL[38]

#define sipType_QOpenGLTexture_TextureFormat sipExportedTypes_QtOpenGL[48]

#define sipType_QOpenGLTexture_TextureUnitReset sipExportedTypes_QtOpenGL[49]

#define sipType_QOpenGLTexture_MipMapGeneration sipExportedTypes_QtOpenGL[42]

#define sipType_QOpenGLTexture_BindingTarget sipExportedTypes_QtOpenGL[34]

#define sipType_QOpenGLTexture_Target sipExportedTypes_QtOpenGL[47]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLTexture;

#define sipType_QOpenGLTextureBlitter sipExportedTypes_QtOpenGL[51]

#define sipType_QOpenGLTextureBlitter_Origin sipExportedTypes_QtOpenGL[52]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLTextureBlitter;

#define sipType_QOpenGLTimerQuery sipExportedTypes_QtOpenGL[54]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLTimerQuery;

#define sipType_QOpenGLTimeMonitor sipExportedTypes_QtOpenGL[53]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLTimeMonitor;

#define sipType_QAbstractOpenGLFunctions sipExportedTypes_QtOpenGL[0]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QAbstractOpenGLFunctions;

#define sipType_QOpenGLVersionFunctionsFactory sipExportedTypes_QtOpenGL[55]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLVersionFunctionsFactory;

#define sipType_QOpenGLVertexArrayObject sipExportedTypes_QtOpenGL[57]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLVertexArrayObject;

#define sipType_QOpenGLVertexArrayObject_Binder sipExportedTypes_QtOpenGL[58]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLVertexArrayObject_Binder;

#define sipType_QOpenGLWindow sipExportedTypes_QtOpenGL[59]

#define sipType_QOpenGLWindow_UpdateBehavior sipExportedTypes_QtOpenGL[60]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLWindow;

#define sipType_QOpenGLFunctions_2_0 sipExportedTypes_QtOpenGL[25]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLFunctions_2_0;

#define sipType_QOpenGLFunctions_2_1 sipExportedTypes_QtOpenGL[26]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLFunctions_2_1;

#define sipType_QOpenGLFunctions_4_1_Core sipExportedTypes_QtOpenGL[27]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLFunctions_4_1_Core;

#define sipType_QOpenGLVersionProfile sipExportedTypes_QtOpenGL[56]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QOpenGLVersionProfile;

#define sipType_QList_0101QOpenGLShader sipExportedTypes_QtOpenGL[9]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_QList_0101QOpenGLShader;

#define sipType_QList_0100QOpenGLDebugMessage sipExportedTypes_QtOpenGL[8]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_QList_0100QOpenGLDebugMessage;

#define sipType_QFlags_0100QOpenGLTexture_Feature sipExportedTypes_QtOpenGL[6]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_QFlags_0100QOpenGLTexture_Feature;

#define sipType_QFlags_0100QOpenGLShader_ShaderTypeBit sipExportedTypes_QtOpenGL[5]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_QFlags_0100QOpenGLShader_ShaderTypeBit;

#define sipType_QFlags_0100QOpenGLDebugMessage_Type sipExportedTypes_QtOpenGL[4]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_QFlags_0100QOpenGLDebugMessage_Type;

#define sipType_QFlags_0100QOpenGLDebugMessage_Source sipExportedTypes_QtOpenGL[3]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_QFlags_0100QOpenGLDebugMessage_Source;

#define sipType_QFlags_0100QOpenGLDebugMessage_Severity sipExportedTypes_QtOpenGL[2]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_QFlags_0100QOpenGLDebugMessage_Severity;

#define sipType_QFlags_0100QOpenGLBuffer_RangeAccessFlag sipExportedTypes_QtOpenGL[1]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_QFlags_0100QOpenGLBuffer_RangeAccessFlag;

#define sipType_std_pair_0100QOpenGLTexture_Filter_0100QOpenGLTexture_Filter sipExportedTypes_QtOpenGL[61]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_std_pair_0100QOpenGLTexture_Filter_0100QOpenGLTexture_Filter;

#define sipType_QList_3900 sipExportedTypes_QtOpenGL[7]

extern sipMappedTypeDef sipTypeDef_QtOpenGL_QList_3900;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtOpenGL;
extern sipExportedModuleDef sipModuleAPI_QtOpenGL;
extern sipTypeDef *sipExportedTypes_QtOpenGL[];

#define sipType_QObject sipImportedTypes_QtOpenGL_QtCore[6].it_td

#define sipType_QByteArray sipImportedTypes_QtOpenGL_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtOpenGL_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtOpenGL_QtCore[14].it_td

#define sipType_QChildEvent sipImportedTypes_QtOpenGL_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtOpenGL_QtCore[5].it_td

#define sipType_QPoint sipImportedTypes_QtOpenGL_QtCore[7].it_td

#define sipType_QPointF sipImportedTypes_QtOpenGL_QtCore[8].it_td

#define sipType_QRect sipImportedTypes_QtOpenGL_QtCore[9].it_td

#define sipType_QRectF sipImportedTypes_QtOpenGL_QtCore[10].it_td

#define sipType_QSize sipImportedTypes_QtOpenGL_QtCore[11].it_td

#define sipType_QSizeF sipImportedTypes_QtOpenGL_QtCore[12].it_td

#define sipType_QList_2200 sipImportedTypes_QtOpenGL_QtCore[3].it_td

#define sipType_QList_1900 sipImportedTypes_QtOpenGL_QtCore[4].it_td

#define sipType_std_pair_2200_2200 sipImportedTypes_QtOpenGL_QtCore[16].it_td

#define sipType_std_pair_1800_1800 sipImportedTypes_QtOpenGL_QtCore[17].it_td

#define sipType_QString sipImportedTypes_QtOpenGL_QtCore[13].it_td

#define sipType_qintptr sipImportedTypes_QtOpenGL_QtCore[15].it_td
extern sipImportedTypeDef sipImportedTypes_QtOpenGL_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtOpenGL_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtOpenGL_QtGui[20].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtOpenGL_QtGui[21].it_td

#define sipType_QColor sipImportedTypes_QtOpenGL_QtGui[1].it_td

#define sipType_QKeyEvent sipImportedTypes_QtOpenGL_QtGui[6].it_td

#define sipType_QFocusEvent sipImportedTypes_QtOpenGL_QtGui[3].it_td

#define sipType_QPaintEvent sipImportedTypes_QtOpenGL_QtGui[24].it_td

#define sipType_QMoveEvent sipImportedTypes_QtOpenGL_QtGui[18].it_td

#define sipType_QResizeEvent sipImportedTypes_QtOpenGL_QtGui[25].it_td

#define sipType_QCloseEvent sipImportedTypes_QtOpenGL_QtGui[0].it_td

#define sipType_QShowEvent sipImportedTypes_QtOpenGL_QtGui[26].it_td

#define sipType_QHideEvent sipImportedTypes_QtOpenGL_QtGui[4].it_td

#define sipType_QExposeEvent sipImportedTypes_QtOpenGL_QtGui[2].it_td

#define sipType_QMouseEvent sipImportedTypes_QtOpenGL_QtGui[17].it_td

#define sipType_QWheelEvent sipImportedTypes_QtOpenGL_QtGui[37].it_td

#define sipType_QTabletEvent sipImportedTypes_QtOpenGL_QtGui[31].it_td

#define sipType_QTouchEvent sipImportedTypes_QtOpenGL_QtGui[32].it_td

#define sipType_QMatrix4x3 sipImportedTypes_QtOpenGL_QtGui[15].it_td

#define sipType_QMatrix4x2 sipImportedTypes_QtOpenGL_QtGui[14].it_td

#define sipType_QMatrix3x4 sipImportedTypes_QtOpenGL_QtGui[13].it_td

#define sipType_QMatrix3x3 sipImportedTypes_QtOpenGL_QtGui[12].it_td

#define sipType_QMatrix3x2 sipImportedTypes_QtOpenGL_QtGui[11].it_td

#define sipType_QMatrix2x4 sipImportedTypes_QtOpenGL_QtGui[10].it_td

#define sipType_QMatrix2x3 sipImportedTypes_QtOpenGL_QtGui[9].it_td

#define sipType_QMatrix2x2 sipImportedTypes_QtOpenGL_QtGui[8].it_td

#define sipType_QImage sipImportedTypes_QtOpenGL_QtGui[5].it_td

#define sipType_QMatrix4x4 sipImportedTypes_QtOpenGL_QtGui[16].it_td

#define sipType_QSurface sipImportedTypes_QtOpenGL_QtGui[27].it_td

#define sipType_QSurface_SurfaceType sipImportedTypes_QtOpenGL_QtGui[28].it_td

#define sipType_QOpenGLContext sipImportedTypes_QtOpenGL_QtGui[19].it_td

#define sipType_QWindow sipImportedTypes_QtOpenGL_QtGui[38].it_td

#define sipType_QPaintDeviceWindow sipImportedTypes_QtOpenGL_QtGui[22].it_td

#define sipType_QPaintEngine sipImportedTypes_QtOpenGL_QtGui[23].it_td

#define sipType_QSurfaceFormat sipImportedTypes_QtOpenGL_QtGui[29].it_td

#define sipType_QSurfaceFormat_OpenGLContextProfile sipImportedTypes_QtOpenGL_QtGui[30].it_td

#define sipType_QTransform sipImportedTypes_QtOpenGL_QtGui[33].it_td

#define sipType_QVector2D sipImportedTypes_QtOpenGL_QtGui[34].it_td

#define sipType_QVector3D sipImportedTypes_QtOpenGL_QtGui[35].it_td

#define sipType_QVector4D sipImportedTypes_QtOpenGL_QtGui[36].it_td

#define sipType_QList_0100QSize sipImportedTypes_QtOpenGL_QtGui[7].it_td
extern sipImportedTypeDef sipImportedTypes_QtOpenGL_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtOpenGL_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtOpenGL_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtOpenGL_qt_metacast;
#line 295 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtOpenGL/qopenglshaderprogram.sip"
#include "qpyopengl_api.h"
#line 3170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtOpenGL/sipAPIQtOpenGL.h"

#endif
